@@ -15,11 +15,18 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+"""
+This module contains AWS Athena hook.
+
+.. spelling::
+
+    PageIterator
+"""
+from __future__ import annotations
 
-"""This module contains AWS Athena hook"""
 import warnings
 from time import sleep
-from typing import Any, Dict, Optional
+from typing import Any
 
 from botocore.paginate import PageIterator
 
@@ -37,7 +44,6 @@ class AthenaHook(AwsBaseHook):
         :class:`~airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
 
     :param sleep_time: Time (in seconds) to wait between two consecutive calls to check query status on Athena
-    :type sleep_time: int
     """
 
     INTERMEDIATE_STATES = (
@@ -49,6 +55,11 @@ class AthenaHook(AwsBaseHook):
         'CANCELLED',
     )
     SUCCESS_STATES = ('SUCCEEDED',)
+    TERMINAL_STATES = (
+        "SUCCEEDED",
+        "FAILED",
+        "CANCELLED",
+    )
 
     def __init__(self, *args: Any, sleep_time: int = 30, **kwargs: Any) -> None:
         super().__init__(client_type='athena', *args, **kwargs)  # type: ignore
@@ -57,24 +68,19 @@ class AthenaHook(AwsBaseHook):
     def run_query(
         self,
         query: str,
-        query_context: Dict[str, str],
-        result_configuration: Dict[str, Any],
-        client_request_token: Optional[str] = None,
+        query_context: dict[str, str],
+        result_configuration: dict[str, Any],
+        client_request_token: str | None = None,
         workgroup: str = 'primary',
     ) -> str:
         """
         Run Presto query on athena with provided config and return submitted query_execution_id
 
         :param query: Presto query to run
-        :type query: str
         :param query_context: Context in which query need to be run
-        :type query_context: dict
         :param result_configuration: Dict with path to store results in and config related to encryption
-        :type result_configuration: dict
         :param client_request_token: Unique token created by user to avoid multiple executions of same query
-        :type client_request_token: str
         :param workgroup: Athena workgroup name, when not specified, will be 'primary'
-        :type workgroup: str
         :return: str
         """
         params = {
@@ -86,15 +92,13 @@ class AthenaHook(AwsBaseHook):
         if client_request_token:
             params['ClientRequestToken'] = client_request_token
         response = self.get_conn().start_query_execution(**params)
-        query_execution_id = response['QueryExecutionId']
-        return query_execution_id
+        return response['QueryExecutionId']
 
-    def check_query_status(self, query_execution_id: str) -> Optional[str]:
+    def check_query_status(self, query_execution_id: str) -> str | None:
         """
         Fetch the status of submitted athena query. Returns None or one of valid query states.
 
         :param query_execution_id: Id of submitted athena query
-        :type query_execution_id: str
         :return: str
         """
         response = self.get_conn().get_query_execution(QueryExecutionId=query_execution_id)
@@ -108,12 +112,11 @@ class AthenaHook(AwsBaseHook):
             # The error is being absorbed to implement retries.
             return state
 
-    def get_state_change_reason(self, query_execution_id: str) -> Optional[str]:
+    def get_state_change_reason(self, query_execution_id: str) -> str | None:
         """
         Fetch the reason for a state change (e.g. error message). Returns None or reason string.
 
         :param query_execution_id: Id of submitted athena query
-        :type query_execution_id: str
         :return: str
         """
         response = self.get_conn().get_query_execution(QueryExecutionId=query_execution_id)
@@ -128,18 +131,15 @@ class AthenaHook(AwsBaseHook):
             return reason
 
     def get_query_results(
-        self, query_execution_id: str, next_token_id: Optional[str] = None, max_results: int = 1000
-    ) -> Optional[dict]:
+        self, query_execution_id: str, next_token_id: str | None = None, max_results: int = 1000
+    ) -> dict | None:
         """
         Fetch submitted athena query results. returns none if query is in intermediate state or
         failed/cancelled state else dict of query output
 
         :param query_execution_id: Id of submitted athena query
-        :type query_execution_id: str
         :param next_token_id:  The token that specifies where to start pagination.
-        :type next_token_id: str
         :param max_results: The maximum number of results (rows) to return in this request.
-        :type max_results: int
         :return: dict
         """
         query_state = self.check_query_status(query_execution_id)
@@ -157,23 +157,19 @@ class AthenaHook(AwsBaseHook):
     def get_query_results_paginator(
         self,
         query_execution_id: str,
-        max_items: Optional[int] = None,
-        page_size: Optional[int] = None,
-        starting_token: Optional[str] = None,
-    ) -> Optional[PageIterator]:
+        max_items: int | None = None,
+        page_size: int | None = None,
+        starting_token: str | None = None,
+    ) -> PageIterator | None:
         """
         Fetch submitted athena query results. returns none if query is in intermediate state or
         failed/cancelled state else a paginator to iterate through pages of results. If you
         wish to get all results at once, call build_full_result() on the returned PageIterator
 
         :param query_execution_id: Id of submitted athena query
-        :type query_execution_id: str
         :param max_items: The total number of items to return.
-        :type max_items: int
         :param page_size: The size of each page.
-        :type page_size: int
         :param starting_token: A token to specify where to start paginating.
-        :type starting_token: str
         :return: PageIterator
         """
         query_state = self.check_query_status(query_execution_id)
@@ -194,34 +190,50 @@ class AthenaHook(AwsBaseHook):
         paginator = self.get_conn().get_paginator('get_query_results')
         return paginator.paginate(**result_params)
 
-    def poll_query_status(self, query_execution_id: str, max_tries: Optional[int] = None) -> Optional[str]:
+    def poll_query_status(
+        self,
+        query_execution_id: str,
+        max_tries: int | None = None,
+        max_polling_attempts: int | None = None,
+    ) -> str | None:
         """
         Poll the status of submitted athena query until query state reaches final state.
         Returns one of the final states
 
         :param query_execution_id: Id of submitted athena query
-        :type query_execution_id: str
-        :param max_tries: Number of times to poll for query state before function exits
-        :type max_tries: int
+        :param max_tries: Deprecated - Use max_polling_attempts instead
+        :param max_polling_attempts: Number of times to poll for query state before function exits
         :return: str
         """
+        if max_tries:
+            warnings.warn(
+                f"Method `{self.__class__.__name__}.max_tries` is deprecated and will be removed "
+                "in a future release.  Please use method `max_polling_attempts` instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+            if max_polling_attempts and max_polling_attempts != max_tries:
+                raise Exception("max_polling_attempts must be the same value as max_tries")
+            else:
+                max_polling_attempts = max_tries
+
         try_number = 1
-        final_query_state = None  # Query state when query reaches final state or max_tries reached
+        final_query_state = None  # Query state when query reaches final state or max_polling_attempts reached
         while True:
             query_state = self.check_query_status(query_execution_id)
             if query_state is None:
                 self.log.info('Trial %s: Invalid query state. Retrying again', try_number)
-            elif query_state in self.INTERMEDIATE_STATES:
-                self.log.info(
-                    'Trial %s: Query is still in an intermediate state - %s', try_number, query_state
-                )
-            else:
+            elif query_state in self.TERMINAL_STATES:
                 self.log.info(
                     'Trial %s: Query execution completed. Final state is %s}', try_number, query_state
                 )
                 final_query_state = query_state
                 break
-            if max_tries and try_number >= max_tries:  # Break loop if max_tries reached
+            else:
+                self.log.info('Trial %s: Query is still in non-terminal state - %s', try_number, query_state)
+            if (
+                max_polling_attempts and try_number >= max_polling_attempts
+            ):  # Break loop if max_polling_attempts reached
                 final_query_state = query_state
                 break
             try_number += 1
@@ -234,7 +246,6 @@ class AthenaHook(AwsBaseHook):
         in s3 uri format.
 
         :param query_execution_id: Id of submitted athena query
-        :type query_execution_id: str
         :return: str
         """
         output_location = None
@@ -247,32 +258,18 @@ class AthenaHook(AwsBaseHook):
                 except KeyError:
                     self.log.error("Error retrieving OutputLocation")
                     raise
+            else:
+                raise
         else:
             raise ValueError("Invalid Query execution id")
 
         return output_location
 
-    def stop_query(self, query_execution_id: str) -> Dict:
+    def stop_query(self, query_execution_id: str) -> dict:
         """
         Cancel the submitted athena query
 
         :param query_execution_id: Id of submitted athena query
-        :type query_execution_id: str
         :return: dict
         """
         return self.get_conn().stop_query_execution(QueryExecutionId=query_execution_id)
-
-
-class AWSAthenaHook(AthenaHook):
-    """
-    This hook is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.hooks.athena.AthenaHook`.
-    """
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This hook is deprecated. Please use `airflow.providers.amazon.aws.hooks.athena.AthenaHook`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        super().__init__(*args, **kwargs)
