@@ -15,22 +15,21 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """
 This module contains Base AWS Hook.
 
 .. seealso::
     For more information on how to use this hook, take a look at the guide:
-    :ref:`howto/connection:AWSHook`
+    :ref:`howto/connection:aws`
 """
+from __future__ import annotations
 
-import configparser
 import datetime
 import json
 import logging
 import warnings
 from functools import wraps
-from typing import Any, Callable, Dict, Generic, Optional, Tuple, Type, TypeVar, Union
+from typing import Any, Callable, Generic, TypeVar, Union
 
 import boto3
 import botocore
@@ -45,10 +44,12 @@ from slugify import slugify
 
 from airflow.compat.functools import cached_property
 from airflow.configuration import conf
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowNotFoundException
 from airflow.hooks.base import BaseHook
 from airflow.models.connection import Connection
+from airflow.providers.amazon.aws.utils.connection_wrapper import AwsConnectionWrapper
 from airflow.utils.log.logging_mixin import LoggingMixin
+from airflow.utils.log.secrets_masker import mask_secret
 
 BaseAwsConnection = TypeVar("BaseAwsConnection", bound=Union[boto3.client, boto3.resource])
 
@@ -65,78 +66,69 @@ class BaseSessionFactory(LoggingMixin):
         :ref:`howto/connection:aws:session-factory`
     """
 
-    def __init__(self, conn: Connection, region_name: Optional[str], config: Config) -> None:
+    def __init__(
+        self,
+        conn: Connection | AwsConnectionWrapper | None,
+        region_name: str | None = None,
+        config: Config | None = None,
+    ) -> None:
         super().__init__()
-        self.conn = conn
-        self.region_name = region_name
-        self.config = config
-        self.extra_config = self.conn.extra_dejson
+        self._conn = conn
+        self._region_name = region_name
+        self._config = config
 
-        self.basic_session: Optional[boto3.session.Session] = None
-        self.role_arn: Optional[str] = None
+    @cached_property
+    def conn(self) -> AwsConnectionWrapper:
+        """Cached AWS Connection Wrapper."""
+        return AwsConnectionWrapper(
+            conn=self._conn,
+            region_name=self._region_name,
+            botocore_config=self._config,
+        )
+
+    @cached_property
+    def basic_session(self) -> boto3.session.Session:
+        """Cached property with basic boto3.session.Session."""
+        return self._create_basic_session(session_kwargs=self.conn.session_kwargs)
+
+    @property
+    def extra_config(self) -> dict[str, Any]:
+        """AWS Connection extra_config."""
+        return self.conn.extra_config
+
+    @property
+    def region_name(self) -> str | None:
+        """AWS Region Name read-only property."""
+        return self.conn.region_name
+
+    @property
+    def config(self) -> Config | None:
+        """Configuration for botocore client read-only property."""
+        return self.conn.botocore_config
+
+    @property
+    def role_arn(self) -> str | None:
+        """Assume Role ARN from AWS Connection"""
+        return self.conn.role_arn
 
     def create_session(self) -> boto3.session.Session:
-        """Create AWS session."""
-        session_kwargs = {}
-        if "session_kwargs" in self.extra_config:
+        """Create boto3 Session from connection config."""
+        if not self.conn:
             self.log.info(
-                "Retrieving session_kwargs from Connection.extra_config['session_kwargs']: %s",
-                self.extra_config["session_kwargs"],
+                "No connection ID provided. Fallback on boto3 credential strategy (region_name=%r). "
+                "See: https://boto3.amazonaws.com/v1/documentation/api/latest/guide/configuration.html",
+                self.region_name,
             )
-            session_kwargs = self.extra_config["session_kwargs"]
-
-        if "profile" in self.extra_config and "s3_config_file" not in self.extra_config:
-            if "profile_name" not in session_kwargs:
-                self.log.warning(
-                    "Found 'profile' without specifying 's3_config_file'. "
-                    "If required profile from AWS Shared Credentials please "
-                    "set 'profile_name' in extra 'session_kwargs'."
-                )
-
-        self.basic_session = self._create_basic_session(session_kwargs=session_kwargs)
-        self.role_arn = self._read_role_arn_from_extra_config()
-        # If role_arn was specified then STS + assume_role
-        if self.role_arn is None:
+            return boto3.session.Session(region_name=self.region_name)
+        elif not self.role_arn:
             return self.basic_session
+        return self._create_session_with_assume_role(session_kwargs=self.conn.session_kwargs)
 
-        return self._create_session_with_assume_role(session_kwargs=session_kwargs)
+    def _create_basic_session(self, session_kwargs: dict[str, Any]) -> boto3.session.Session:
+        return boto3.session.Session(**session_kwargs)
 
-    def _get_region_name(self) -> Optional[str]:
-        region_name = self.region_name
-        if self.region_name is None and 'region_name' in self.extra_config:
-            self.log.info("Retrieving region_name from Connection.extra_config['region_name']")
-            region_name = self.extra_config["region_name"]
-        return region_name
-
-    def _create_basic_session(self, session_kwargs: Dict[str, Any]) -> boto3.session.Session:
-        aws_access_key_id, aws_secret_access_key = self._read_credentials_from_connection()
-        aws_session_token = self.extra_config.get("aws_session_token")
-        region_name = self._get_region_name()
-        self.log.debug(
-            "Creating session with aws_access_key_id=%s region_name=%s",
-            aws_access_key_id,
-            region_name,
-        )
-
-        return boto3.session.Session(
-            aws_access_key_id=aws_access_key_id,
-            aws_secret_access_key=aws_secret_access_key,
-            region_name=region_name,
-            aws_session_token=aws_session_token,
-            **session_kwargs,
-        )
-
-    def _create_session_with_assume_role(self, session_kwargs: Dict[str, Any]) -> boto3.session.Session:
-        assume_role_method = self.extra_config.get('assume_role_method', 'assume_role')
-        self.log.debug("assume_role_method=%s", assume_role_method)
-        supported_methods = ['assume_role', 'assume_role_with_saml', 'assume_role_with_web_identity']
-        if assume_role_method not in supported_methods:
-            raise NotImplementedError(
-                f'assume_role_method={assume_role_method} in Connection {self.conn.conn_id} Extra.'
-                f'Currently {supported_methods} are supported.'
-                '(Exclude this setting will default to "assume_role").'
-            )
-        if assume_role_method == 'assume_role_with_web_identity':
+    def _create_session_with_assume_role(self, session_kwargs: dict[str, Any]) -> boto3.session.Session:
+        if self.conn.assume_role_method == 'assume_role_with_web_identity':
             # Deferred credentials have no initial credentials
             credential_fetcher = self._get_web_identity_credential_fetcher()
             credentials = botocore.credentials.DeferredRefreshableCredentials(
@@ -151,38 +143,31 @@ class BaseSessionFactory(LoggingMixin):
                 refresh_using=self._refresh_credentials,
                 method="sts-assume-role",
             )
+
         session = botocore.session.get_session()
         session._credentials = credentials
-
-        if self.basic_session is None:
-            raise RuntimeError("The basic session should be created here!")
-
         region_name = self.basic_session.region_name
         session.set_config_variable("region", region_name)
 
         return boto3.session.Session(botocore_session=session, **session_kwargs)
 
-    def _refresh_credentials(self) -> Dict[str, Any]:
+    def _refresh_credentials(self) -> dict[str, Any]:
         self.log.debug('Refreshing credentials')
-        assume_role_method = self.extra_config.get('assume_role_method', 'assume_role')
-        sts_session = self.basic_session
+        assume_role_method = self.conn.assume_role_method
+        if assume_role_method not in ('assume_role', 'assume_role_with_saml'):
+            raise NotImplementedError(f'assume_role_method={assume_role_method} not expected')
 
-        if sts_session is None:
-            raise RuntimeError(
-                "Session should be initialized when refresh credentials with assume_role is used!"
-            )
-
-        sts_client = sts_session.client("sts", config=self.config)
+        sts_client = self.basic_session.client("sts", config=self.config)
 
         if assume_role_method == 'assume_role':
             sts_response = self._assume_role(sts_client=sts_client)
-        elif assume_role_method == 'assume_role_with_saml':
-            sts_response = self._assume_role_with_saml(sts_client=sts_client)
         else:
-            raise NotImplementedError(f'assume_role_method={assume_role_method} not expected')
+            sts_response = self._assume_role_with_saml(sts_client=sts_client)
+
         sts_response_http_status = sts_response['ResponseMetadata']['HTTPStatusCode']
-        if not sts_response_http_status == 200:
+        if sts_response_http_status != 200:
             raise RuntimeError(f'sts_response_http_status={sts_response_http_status}')
+
         credentials = sts_response['Credentials']
         expiry_time = credentials.get('Expiration').isoformat()
         self.log.debug('New credentials expiry_time: %s', expiry_time)
@@ -194,72 +179,15 @@ class BaseSessionFactory(LoggingMixin):
         }
         return credentials
 
-    def _read_role_arn_from_extra_config(self) -> Optional[str]:
-        aws_account_id = self.extra_config.get("aws_account_id")
-        aws_iam_role = self.extra_config.get("aws_iam_role")
-        role_arn = self.extra_config.get("role_arn")
-        if role_arn is None and aws_account_id is not None and aws_iam_role is not None:
-            self.log.info("Constructing role_arn from aws_account_id and aws_iam_role")
-            warnings.warn(
-                "Constructing 'role_arn' from 'aws_account_id' and 'aws_iam_role' is deprecated and "
-                "will be removed in a future releases. Please set 'role_arn' in extra config.",
-                DeprecationWarning,
-                stacklevel=3,
-            )
-            role_arn = f"arn:aws:iam::{aws_account_id}:role/{aws_iam_role}"
-        self.log.debug("role_arn is %s", role_arn)
-        return role_arn
+    def _assume_role(self, sts_client: boto3.client) -> dict:
+        kw = {
+            "RoleSessionName": self._strip_invalid_session_name_characters(f"Airflow_{self.conn.conn_id}"),
+            **self.conn.assume_role_kwargs,
+            "RoleArn": self.role_arn,
+        }
+        return sts_client.assume_role(**kw)
 
-    def _read_credentials_from_connection(self) -> Tuple[Optional[str], Optional[str]]:
-        aws_access_key_id = None
-        aws_secret_access_key = None
-        if self.conn.login:
-            aws_access_key_id = self.conn.login
-            aws_secret_access_key = self.conn.password
-            self.log.info("Credentials retrieved from login")
-        elif "aws_access_key_id" in self.extra_config and "aws_secret_access_key" in self.extra_config:
-            aws_access_key_id = self.extra_config["aws_access_key_id"]
-            aws_secret_access_key = self.extra_config["aws_secret_access_key"]
-            self.log.info("Credentials retrieved from extra_config")
-        elif "s3_config_file" in self.extra_config:
-            warnings.warn(
-                "Use local credentials file is never documented and well tested. "
-                "Obtain credentials by this way deprecated and will be removed in a future releases.",
-                DeprecationWarning,
-                stacklevel=3,
-            )
-            aws_access_key_id, aws_secret_access_key = _parse_s3_config(
-                self.extra_config["s3_config_file"],
-                self.extra_config.get("s3_config_format"),
-                self.extra_config.get("profile"),
-            )
-            self.log.info("Credentials retrieved from extra_config['s3_config_file']")
-        return aws_access_key_id, aws_secret_access_key
-
-    def _strip_invalid_session_name_characters(self, role_session_name: str) -> str:
-        return slugify(role_session_name, regex_pattern=r'[^\w+=,.@-]+')
-
-    def _assume_role(self, sts_client: boto3.client) -> Dict:
-        assume_role_kwargs = self.extra_config.get("assume_role_kwargs", {})
-        if "ExternalId" not in assume_role_kwargs and "external_id" in self.extra_config:
-            warnings.warn(
-                "'external_id' in extra config is deprecated and will be removed in a future releases. "
-                "Set 'ExternalId' in 'assume_role_kwargs' in extra config.",
-                DeprecationWarning,
-                stacklevel=3,
-            )
-            assume_role_kwargs["ExternalId"] = self.extra_config.get("external_id")
-        role_session_name = self._strip_invalid_session_name_characters(f"Airflow_{self.conn.conn_id}")
-        self.log.debug(
-            "Doing sts_client.assume_role to role_arn=%s (role_session_name=%s)",
-            self.role_arn,
-            role_session_name,
-        )
-        return sts_client.assume_role(
-            RoleArn=self.role_arn, RoleSessionName=role_session_name, **assume_role_kwargs
-        )
-
-    def _assume_role_with_saml(self, sts_client: boto3.client) -> Dict[str, Any]:
+    def _assume_role_with_saml(self, sts_client: boto3.client) -> dict[str, Any]:
         saml_config = self.extra_config['assume_role_with_saml']
         principal_arn = saml_config['principal_arn']
 
@@ -273,16 +201,15 @@ class BaseSessionFactory(LoggingMixin):
             )
 
         self.log.debug("Doing sts_client.assume_role_with_saml to role_arn=%s", self.role_arn)
-        assume_role_kwargs = self.extra_config.get("assume_role_kwargs", {})
         return sts_client.assume_role_with_saml(
             RoleArn=self.role_arn,
             PrincipalArn=principal_arn,
             SAMLAssertion=saml_assertion,
-            **assume_role_kwargs,
+            **self.conn.assume_role_kwargs,
         )
 
     def _get_idp_response(
-        self, saml_config: Dict[str, Any], auth: requests.auth.AuthBase
+        self, saml_config: dict[str, Any], auth: requests.auth.AuthBase
     ) -> requests.models.Response:
         idp_url = saml_config["idp_url"]
         self.log.debug("idp_url= %s", idp_url)
@@ -310,7 +237,7 @@ class BaseSessionFactory(LoggingMixin):
 
         return idp_response
 
-    def _fetch_saml_assertion_using_http_spegno_auth(self, saml_config: Dict[str, Any]) -> str:
+    def _fetch_saml_assertion_using_http_spegno_auth(self, saml_config: dict[str, Any]) -> str:
         # requests_gssapi will need paramiko > 2.6 since you'll need
         # 'gssapi' not 'python-gssapi' from PyPi.
         # https://github.com/paramiko/paramiko/pull/1311
@@ -357,8 +284,6 @@ class BaseSessionFactory(LoggingMixin):
     def _get_web_identity_credential_fetcher(
         self,
     ) -> botocore.credentials.AssumeRoleWithWebIdentityCredentialFetcher:
-        if self.basic_session is None:
-            raise Exception("Session should be set where identity is fetched!")
         base_session = self.basic_session._session or botocore.session.get_session()
         client_creator = base_session.create_client
         federation = self.extra_config.get('assume_role_with_web_identity_federation')
@@ -368,12 +293,11 @@ class BaseSessionFactory(LoggingMixin):
             raise AirflowException(
                 f'Unsupported federation: {federation}. Currently "google" only are supported.'
             )
-        assume_role_kwargs = self.extra_config.get("assume_role_kwargs", {})
         return botocore.credentials.AssumeRoleWithWebIdentityCredentialFetcher(
             client_creator=client_creator,
             web_identity_token_loader=web_identity_token_loader,
             role_arn=self.role_arn,
-            extra_args=assume_role_kwargs,
+            extra_args=self.conn.assume_role_kwargs,
         )
 
     def _get_google_identity_token_loader(self):
@@ -395,6 +319,37 @@ class BaseSessionFactory(LoggingMixin):
 
         return web_identity_token_loader
 
+    def _strip_invalid_session_name_characters(self, role_session_name: str) -> str:
+        return slugify(role_session_name, regex_pattern=r'[^\w+=,.@-]+')
+
+    def _get_region_name(self) -> str | None:
+        warnings.warn(
+            "`BaseSessionFactory._get_region_name` method deprecated and will be removed "
+            "in a future releases. Please use `BaseSessionFactory.region_name` property instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return self.region_name
+
+    def _read_role_arn_from_extra_config(self) -> str | None:
+        warnings.warn(
+            "`BaseSessionFactory._read_role_arn_from_extra_config` method deprecated and will be removed "
+            "in a future releases. Please use `BaseSessionFactory.role_arn` property instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return self.role_arn
+
+    def _read_credentials_from_connection(self) -> tuple[str | None, str | None]:
+        warnings.warn(
+            "`BaseSessionFactory._read_credentials_from_connection` method deprecated and will be removed "
+            "in a future releases. Please use `BaseSessionFactory.conn.aws_access_key_id` and "
+            "`BaseSessionFactory.aws_secret_access_key` properties instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return self.conn.aws_access_key_id, self.conn.aws_secret_access_key
+
 
 class AwsGenericHook(BaseHook, Generic[BaseAwsConnection]):
     """
@@ -422,115 +377,102 @@ class AwsGenericHook(BaseHook, Generic[BaseAwsConnection]):
 
     def __init__(
         self,
-        aws_conn_id: Optional[str] = default_conn_name,
-        verify: Union[bool, str, None] = None,
-        region_name: Optional[str] = None,
-        client_type: Optional[str] = None,
-        resource_type: Optional[str] = None,
-        config: Optional[Config] = None,
+        aws_conn_id: str | None = default_conn_name,
+        verify: bool | str | None = None,
+        region_name: str | None = None,
+        client_type: str | None = None,
+        resource_type: str | None = None,
+        config: Config | None = None,
     ) -> None:
         super().__init__()
         self.aws_conn_id = aws_conn_id
-        self.verify = verify
         self.client_type = client_type
         self.resource_type = resource_type
-        self.region_name = region_name
-        self.config = config
 
-    def _get_credentials(self, region_name: Optional[str]) -> Tuple[boto3.session.Session, Optional[str]]:
+        self._region_name = region_name
+        self._config = config
+        self._verify = verify
 
-        if not self.aws_conn_id:
-            session = boto3.session.Session(region_name=region_name)
-            return session, None
-
-        self.log.debug("Airflow Connection: aws_conn_id=%s", self.aws_conn_id)
-
-        try:
-            # Fetch the Airflow connection object
-            connection_object = self.get_connection(self.aws_conn_id)
-            extra_config = connection_object.extra_dejson
-            endpoint_url = extra_config.get("host")
-
-            # https://botocore.amazonaws.com/v1/documentation/api/latest/reference/config.html
-            if "config_kwargs" in extra_config:
-                self.log.debug(
-                    "Retrieving config_kwargs from Connection.extra_config['config_kwargs']: %s",
-                    extra_config["config_kwargs"],
+    @cached_property
+    def conn_config(self) -> AwsConnectionWrapper:
+        """Get the Airflow Connection object and wrap it in helper (cached)."""
+        connection = None
+        if self.aws_conn_id:
+            try:
+                connection = self.get_connection(self.aws_conn_id)
+            except AirflowNotFoundException:
+                warnings.warn(
+                    f"Unable to find AWS Connection ID '{self.aws_conn_id}', switching to empty. "
+                    "This behaviour is deprecated and will be removed in a future releases. "
+                    "Please provide existed AWS connection ID or if required boto3 credential strategy "
+                    "explicit set AWS Connection ID to None.",
+                    DeprecationWarning,
+                    stacklevel=2,
                 )
-                self.config = Config(**extra_config["config_kwargs"])
 
-            session = SessionFactory(
-                conn=connection_object, region_name=region_name, config=self.config
-            ).create_session()
-
-            return session, endpoint_url
-
-        except AirflowException:
-            self.log.warning(
-                "Unable to use Airflow Connection for credentials. "
-                "Fallback on boto3 credential strategy. See: "
-                "https://boto3.amazonaws.com/v1/documentation/api/latest/guide/configuration.html"
-            )
-
-        self.log.debug(
-            "Creating session using boto3 credential strategy region_name=%s",
-            region_name,
+        return AwsConnectionWrapper(
+            conn=connection, region_name=self._region_name, botocore_config=self._config, verify=self._verify
         )
-        session = boto3.session.Session(region_name=region_name)
-        return session, None
+
+    @property
+    def region_name(self) -> str | None:
+        """AWS Region Name read-only property."""
+        return self.conn_config.region_name
+
+    @property
+    def config(self) -> Config | None:
+        """Configuration for botocore client read-only property."""
+        return self.conn_config.botocore_config
+
+    @property
+    def verify(self) -> bool | str | None:
+        """Verify or not SSL certificates boto3 client/resource read-only property."""
+        return self.conn_config.verify
+
+    def get_session(self, region_name: str | None = None) -> boto3.session.Session:
+        """Get the underlying boto3.session.Session(region_name=region_name)."""
+        return SessionFactory(
+            conn=self.conn_config, region_name=region_name, config=self.config
+        ).create_session()
 
     def get_client_type(
         self,
-        client_type: Optional[str] = None,
-        region_name: Optional[str] = None,
-        config: Optional[Config] = None,
+        region_name: str | None = None,
+        config: Config | None = None,
     ) -> boto3.client:
         """Get the underlying boto3 client using boto3 session"""
-        session, endpoint_url = self._get_credentials(region_name=region_name)
-
-        if client_type:
-            warnings.warn(
-                "client_type is deprecated. Set client_type from class attribute.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-        else:
-            client_type = self.client_type
+        client_type = self.client_type
 
         # No AWS Operators use the config argument to this method.
         # Keep backward compatibility with other users who might use it
         if config is None:
             config = self.config
 
-        return session.client(client_type, endpoint_url=endpoint_url, config=config, verify=self.verify)
+        session = self.get_session(region_name=region_name)
+        return session.client(
+            client_type, endpoint_url=self.conn_config.endpoint_url, config=config, verify=self.verify
+        )
 
     def get_resource_type(
         self,
-        resource_type: Optional[str] = None,
-        region_name: Optional[str] = None,
-        config: Optional[Config] = None,
+        region_name: str | None = None,
+        config: Config | None = None,
     ) -> boto3.resource:
         """Get the underlying boto3 resource using boto3 session"""
-        session, endpoint_url = self._get_credentials(region_name=region_name)
-
-        if resource_type:
-            warnings.warn(
-                "resource_type is deprecated. Set resource_type from class attribute.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-        else:
-            resource_type = self.resource_type
+        resource_type = self.resource_type
 
         # No AWS Operators use the config argument to this method.
         # Keep backward compatibility with other users who might use it
         if config is None:
             config = self.config
 
-        return session.resource(resource_type, endpoint_url=endpoint_url, config=config, verify=self.verify)
+        session = self.get_session(region_name=region_name)
+        return session.resource(
+            resource_type, endpoint_url=self.conn_config.endpoint_url, config=config, verify=self.verify
+        )
 
     @cached_property
-    def conn(self) -> Union[boto3.client, boto3.resource]:
+    def conn(self) -> BaseAwsConnection:
         """
         Get the underlying boto3 client/resource (cached)
 
@@ -549,6 +491,7 @@ class AwsGenericHook(BaseHook, Generic[BaseAwsConnection]):
 
     @cached_property
     def conn_client_meta(self) -> ClientMeta:
+        """Get botocore client metadata from Hook connection (cached)."""
         conn = self.conn
         if isinstance(conn, botocore.client.BaseClient):
             return conn.meta
@@ -556,10 +499,12 @@ class AwsGenericHook(BaseHook, Generic[BaseAwsConnection]):
 
     @property
     def conn_region_name(self) -> str:
+        """Get actual AWS Region Name from Hook connection (cached)."""
         return self.conn_client_meta.region_name
 
     @property
     def conn_partition(self) -> str:
+        """Get associated AWS Region Partition from Hook connection (cached)."""
         return self.conn_client_meta.partition
 
     def get_conn(self) -> BaseAwsConnection:
@@ -575,24 +520,23 @@ class AwsGenericHook(BaseHook, Generic[BaseAwsConnection]):
         # Compat shim
         return self.conn
 
-    def get_session(self, region_name: Optional[str] = None) -> boto3.session.Session:
-        """Get the underlying boto3.session."""
-        session, _ = self._get_credentials(region_name=region_name)
-        return session
-
-    def get_credentials(self, region_name: Optional[str] = None) -> ReadOnlyCredentials:
+    def get_credentials(self, region_name: str | None = None) -> ReadOnlyCredentials:
         """
         Get the underlying `botocore.Credentials` object.
 
         This contains the following authentication attributes: access_key, secret_key and token.
+        By use this method also secret_key and token will mask in tasks logs.
         """
-        session, _ = self._get_credentials(region_name=region_name)
         # Credentials are refreshable, so accessing your access key and
         # secret key separately can lead to a race condition.
         # See https://stackoverflow.com/a/36291428/8283373
-        return session.get_credentials().get_frozen_credentials()
+        creds = self.get_session(region_name=region_name).get_credentials().get_frozen_credentials()
+        mask_secret(creds.secret_key)
+        if creds.token:
+            mask_secret(creds.token)
+        return creds
 
-    def expand_role(self, role: str, region_name: Optional[str] = None) -> str:
+    def expand_role(self, role: str, region_name: str | None = None) -> str:
         """
         If the IAM role is a role name, get the Amazon Resource Name (ARN) for the role.
         If IAM role is already an IAM role ARN, no change is made.
@@ -604,8 +548,10 @@ class AwsGenericHook(BaseHook, Generic[BaseAwsConnection]):
         if "/" in role:
             return role
         else:
-            session, endpoint_url = self._get_credentials(region_name=region_name)
-            _client = session.client('iam', endpoint_url=endpoint_url, config=self.config, verify=self.verify)
+            session = self.get_session(region_name=region_name)
+            _client = session.client(
+                'iam', endpoint_url=self.conn_config.endpoint_url, config=self.config, verify=self.verify
+            )
             return _client.get_role(RoleName=role)["Role"]["Arn"]
 
     @staticmethod
@@ -640,6 +586,45 @@ class AwsGenericHook(BaseHook, Generic[BaseAwsConnection]):
 
         return retry_decorator
 
+    def _get_credentials(self, region_name: str | None) -> tuple[boto3.session.Session, str | None]:
+        warnings.warn(
+            "`AwsGenericHook._get_credentials` method deprecated and will be removed in a future releases. "
+            "Please use `AwsGenericHook.get_session` method and "
+            "`AwsGenericHook.conn_config.endpoint_url` property instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+
+        return self.get_session(region_name=region_name), self.conn_config.endpoint_url
+
+    @staticmethod
+    def get_ui_field_behaviour() -> dict[str, Any]:
+        """Returns custom UI field behaviour for AWS Connection."""
+        return {
+            "hidden_fields": ["host", "schema", "port"],
+            "relabeling": {
+                "login": "AWS Access Key ID",
+                "password": "AWS Secret Access Key",
+            },
+            "placeholders": {
+                "login": "AKIAIOSFODNN7EXAMPLE",
+                "password": "wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY",
+                "extra": json.dumps(
+                    {
+                        "region_name": "us-east-1",
+                        "session_kwargs": {"profile_name": "default"},
+                        "config_kwargs": {"retries": {"mode": "standard", "max_attempts": 10}},
+                        "role_arn": "arn:aws:iam::123456789098:role/role-name",
+                        "assume_role_method": "assume_role",
+                        "assume_role_kwargs": {"RoleSessionName": "airflow"},
+                        "aws_session_token": "AQoDYXdzEJr...EXAMPLETOKEN",
+                        "endpoint_url": "http://localhost:4566",
+                    },
+                    indent=2,
+                ),
+            },
+        }
+
     def test_connection(self):
         """
         Tests the AWS connection by call AWS STS (Security Token Service) GetCallerIdentity API.
@@ -675,58 +660,7 @@ class AwsBaseHook(AwsGenericHook[Union[boto3.client, boto3.resource]]):
     """
 
 
-def _parse_s3_config(
-    config_file_name: str, config_format: Optional[str] = "boto", profile: Optional[str] = None
-) -> Tuple[Optional[str], Optional[str]]:
-    """
-    Parses a config file for s3 credentials. Can currently
-    parse boto, s3cmd.conf and AWS SDK config formats
-
-    :param config_file_name: path to the config file
-    :param config_format: config type. One of "boto", "s3cmd" or "aws".
-        Defaults to "boto"
-    :param profile: profile name in AWS type config file
-    """
-    config = configparser.ConfigParser()
-    if config.read(config_file_name):  # pragma: no cover
-        sections = config.sections()
-    else:
-        raise AirflowException(f"Couldn't read {config_file_name}")
-    # Setting option names depending on file format
-    if config_format is None:
-        config_format = "boto"
-    conf_format = config_format.lower()
-    if conf_format == "boto":  # pragma: no cover
-        if profile is not None and "profile " + profile in sections:
-            cred_section = "profile " + profile
-        else:
-            cred_section = "Credentials"
-    elif conf_format == "aws" and profile is not None:
-        cred_section = profile
-    else:
-        cred_section = "default"
-    # Option names
-    if conf_format in ("boto", "aws"):  # pragma: no cover
-        key_id_option = "aws_access_key_id"
-        secret_key_option = "aws_secret_access_key"
-        # security_token_option = 'aws_security_token'
-    else:
-        key_id_option = "access_key"
-        secret_key_option = "secret_key"
-    # Actual Parsing
-    if cred_section not in sections:
-        raise AirflowException("This config file format is not recognized")
-    else:
-        try:
-            access_key = config.get(cred_section, key_id_option)
-            secret_key = config.get(cred_section, secret_key_option)
-        except Exception:
-            logging.warning("Option Error in parsing s3 config file")
-            raise
-        return access_key, secret_key
-
-
-def resolve_session_factory() -> Type[BaseSessionFactory]:
+def resolve_session_factory() -> type[BaseSessionFactory]:
     """Resolves custom SessionFactory class"""
     clazz = conf.getimport("aws", "session_factory", fallback=None)
     if not clazz:
@@ -740,3 +674,14 @@ def resolve_session_factory() -> Type[BaseSessionFactory]:
 
 
 SessionFactory = resolve_session_factory()
+
+
+def _parse_s3_config(config_file_name: str, config_format: str | None = "boto", profile: str | None = None):
+    """For compatibility with airflow.contrib.hooks.aws_hook"""
+    from airflow.providers.amazon.aws.utils.connection_wrapper import _parse_s3_config
+
+    return _parse_s3_config(
+        config_file_name=config_file_name,
+        config_format=config_format,
+        profile=profile,
+    )
