@@ -15,10 +15,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """This module contains AWS CloudFormation Hook"""
-import warnings
-from typing import Optional, Union
+from __future__ import annotations
 
 from boto3 import client, resource
 from botocore.exceptions import ClientError
@@ -40,7 +38,7 @@ class CloudFormationHook(AwsBaseHook):
     def __init__(self, *args, **kwargs):
         super().__init__(client_type='cloudformation', *args, **kwargs)
 
-    def get_stack_status(self, stack_name: Union[client, resource]) -> Optional[dict]:
+    def get_stack_status(self, stack_name: client | resource) -> dict | None:
         """Get stack status from CloudFormation."""
         self.log.info('Poking for stack %s', stack_name)
 
@@ -53,45 +51,25 @@ class CloudFormationHook(AwsBaseHook):
             else:
                 raise e
 
-    def create_stack(self, stack_name: str, params: dict) -> None:
+    def create_stack(self, stack_name: str, cloudformation_parameters: dict) -> None:
         """
         Create stack in CloudFormation.
 
         :param stack_name: stack_name.
-        :type stack_name: str
-        :param params: parameters to be passed to CloudFormation.
-        :type params: dict
+        :param cloudformation_parameters: parameters to be passed to CloudFormation.
         """
-        if 'StackName' not in params:
-            params['StackName'] = stack_name
-        self.get_conn().create_stack(**params)
+        if 'StackName' not in cloudformation_parameters:
+            cloudformation_parameters['StackName'] = stack_name
+        self.get_conn().create_stack(**cloudformation_parameters)
 
-    def delete_stack(self, stack_name: str, params: Optional[dict] = None) -> None:
+    def delete_stack(self, stack_name: str, cloudformation_parameters: dict | None = None) -> None:
         """
         Delete stack in CloudFormation.
 
         :param stack_name: stack_name.
-        :type stack_name: str
-        :param params: parameters to be passed to CloudFormation (optional).
-        :type params: dict
+        :param cloudformation_parameters: parameters to be passed to CloudFormation (optional).
         """
-        params = params or {}
-        if 'StackName' not in params:
-            params['StackName'] = stack_name
-        self.get_conn().delete_stack(**params)
-
-
-class AWSCloudFormationHook(CloudFormationHook):
-    """
-    This hook is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.hooks.cloud_formation.CloudFormationHook`.
-    """
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This hook is deprecated. "
-            "Please use :class:`airflow.providers.amazon.aws.hooks.cloud_formation.CloudFormationHook`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        super().__init__(*args, **kwargs)
+        cloudformation_parameters = cloudformation_parameters or {}
+        if 'StackName' not in cloudformation_parameters:
+            cloudformation_parameters['StackName'] = stack_name
+        self.get_conn().delete_stack(**cloudformation_parameters)
