@@ -14,12 +14,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """Interact with AWS DataSync, using the AWS ``boto3`` library."""
+from __future__ import annotations
 
 import time
-import warnings
-from typing import List, Optional
 
 from airflow.exceptions import AirflowBadRequest, AirflowException, AirflowTaskTimeout
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
@@ -38,7 +36,6 @@ class DataSyncHook(AwsBaseHook):
 
     :param wait_interval_seconds: Time to wait between two
         consecutive calls to check TaskExecution status. Defaults to 30 seconds.
-    :type wait_interval_seconds: Optional[int]
     :raises ValueError: If wait_interval_seconds is not between 0 and 15*60 seconds.
     """
 
@@ -87,7 +84,7 @@ class DataSyncHook(AwsBaseHook):
 
     def get_location_arns(
         self, location_uri: str, case_sensitive: bool = False, ignore_trailing_slash: bool = True
-    ) -> List[str]:
+    ) -> list[str]:
         """
         Return all LocationArns which match a LocationUri.
 
@@ -264,7 +261,7 @@ class DataSyncHook(AwsBaseHook):
         """
         return self.get_conn().describe_task_execution(TaskExecutionArn=task_execution_arn)
 
-    def get_current_task_execution_arn(self, task_arn: str) -> Optional[str]:
+    def get_current_task_execution_arn(self, task_arn: str) -> str | None:
         """
         Get current TaskExecutionArn (if one exists) for the specified ``task_arn``.
 
@@ -317,18 +314,3 @@ class DataSyncHook(AwsBaseHook):
         if iterations <= 0:
             raise AirflowTaskTimeout("Max iterations exceeded!")
         raise AirflowException(f"Unknown status: {status}")  # Should never happen
-
-
-class AWSDataSyncHook(DataSyncHook):
-    """
-    This hook is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.hooks.datasync.DataSyncHook`.
-    """
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This hook is deprecated. Please use `airflow.providers.amazon.aws.hooks.datasync.DataSyncHook`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        super().__init__(*args, **kwargs)
