@@ -15,9 +15,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
+
 import json
 from enum import Enum
-from typing import Optional
 
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 
@@ -47,27 +48,22 @@ class DmsHook(AwsBaseHook):
         Describe replication tasks
 
         :return: Marker and list of replication tasks
-        :rtype: (str, list)
+        :rtype: (Optional[str], list)
         """
         dms_client = self.get_conn()
         response = dms_client.describe_replication_tasks(**kwargs)
 
-        return response['Marker'], response['ReplicationTasks']
+        return response.get('Marker'), response.get('ReplicationTasks', [])
 
-    def find_replication_tasks_by_arn(
-        self, replication_task_arn: str, without_settings: Optional[bool] = False
-    ):
+    def find_replication_tasks_by_arn(self, replication_task_arn: str, without_settings: bool | None = False):
         """
         Find and describe replication tasks by task ARN
         :param replication_task_arn: Replication task arn
-        :type replication_task_arn: str
         :param without_settings: Indicates whether to return task information with settings.
-        :type without_settings: Optional[bool]
 
         :return: list of replication tasks that match the ARN
         """
-        dms_client = self.get_conn()
-        response = dms_client.describe_replication_tasks(
+        _, tasks = self.describe_replication_tasks(
             Filters=[
                 {
                     'Name': 'replication-task-arn',
@@ -77,14 +73,13 @@ class DmsHook(AwsBaseHook):
             WithoutSettings=without_settings,
         )
 
-        return response['ReplicationTasks']
+        return tasks
 
-    def get_task_status(self, replication_task_arn: str) -> Optional[str]:
+    def get_task_status(self, replication_task_arn: str) -> str | None:
         """
         Retrieve task status.
 
         :param replication_task_arn: Replication task ARN
-        :type replication_task_arn: str
         :return: Current task status
         """
         replication_tasks = self.find_replication_tasks_by_arn(
@@ -114,17 +109,11 @@ class DmsHook(AwsBaseHook):
         Create DMS replication task
 
         :param replication_task_id: Replication task id
-        :type replication_task_id: str
         :param source_endpoint_arn: Source endpoint ARN
-        :type source_endpoint_arn: str
         :param target_endpoint_arn: Target endpoint ARN
-        :type target_endpoint_arn: str
         :param replication_instance_arn: Replication instance ARN
-        :type replication_instance_arn: str
         :param table_mappings: Table mappings
-        :type table_mappings: dict
         :param migration_type: Migration type ('full-load'|'cdc'|'full-load-and-cdc'), full-load by default.
-        :type migration_type: str
         :return: Replication task ARN
         """
         dms_client = self.get_conn()
@@ -153,10 +142,8 @@ class DmsHook(AwsBaseHook):
         Starts replication task.
 
         :param replication_task_arn: Replication task ARN
-        :type replication_task_arn: str
-        :param start_replication_task_type: Replication task start type
+        :param start_replication_task_type: Replication task start type (default='start-replication')
             ('start-replication'|'resume-processing'|'reload-target')
-        :type start_replication_task_type: str
         """
         dms_client = self.get_conn()
         dms_client.start_replication_task(
@@ -170,7 +157,6 @@ class DmsHook(AwsBaseHook):
         Stops replication task.
 
         :param replication_task_arn: Replication task ARN
-        :type replication_task_arn: str
         """
         dms_client = self.get_conn()
         dms_client.stop_replication_task(ReplicationTaskArn=replication_task_arn)
@@ -180,7 +166,6 @@ class DmsHook(AwsBaseHook):
         Starts replication task deletion and waits for it to be deleted
 
         :param replication_task_arn: Replication task ARN
-        :type replication_task_arn: str
         """
         dms_client = self.get_conn()
         dms_client.delete_replication_task(ReplicationTaskArn=replication_task_arn)
@@ -193,9 +178,7 @@ class DmsHook(AwsBaseHook):
         Supported statuses: deleted, ready, running, stopped.
 
         :param status: Status to wait for
-        :type status: DmsTaskWaiterStatus
         :param replication_task_arn: Replication task ARN
-        :type replication_task_arn: str
         """
         if not isinstance(status, DmsTaskWaiterStatus):
             raise TypeError('Status must be an instance of DmsTaskWaiterStatus')
