@@ -15,11 +15,15 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
+
+import warnings
 from time import sleep
-from typing import Any, Dict, List, Optional
+from typing import Any, Callable
 
 from botocore.exceptions import ClientError
 
+from airflow.compat.functools import cached_property
 from airflow.exceptions import AirflowException, AirflowNotFoundException
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 
@@ -46,7 +50,7 @@ class EmrHook(AwsBaseHook):
         kwargs["client_type"] = "emr"
         super().__init__(*args, **kwargs)
 
-    def get_cluster_id_by_name(self, emr_cluster_name: str, cluster_states: List[str]) -> Optional[str]:
+    def get_cluster_id_by_name(self, emr_cluster_name: str, cluster_states: list[str]) -> str | None:
         """
         Fetch id of EMR cluster with given name and (optional) states.
         Will return only if single id is found.
@@ -71,7 +75,7 @@ class EmrHook(AwsBaseHook):
             self.log.info('No cluster found for name %s', emr_cluster_name)
             return None
 
-    def create_job_flow(self, job_flow_overrides: Dict[str, Any]) -> Dict[str, Any]:
+    def create_job_flow(self, job_flow_overrides: dict[str, Any]) -> dict[str, Any]:
         """
         Creates a job flow using the config from the EMR connection.
         Keys of the json extra hash may have the arguments of the boto3
@@ -90,6 +94,87 @@ class EmrHook(AwsBaseHook):
         return response
 
 
+class EmrServerlessHook(AwsBaseHook):
+    """
+    Interact with EMR Serverless API.
+
+    Additional arguments (such as ``aws_conn_id``) may be specified and
+    are passed down to the underlying AwsBaseHook.
+
+    .. seealso::
+        :class:`~airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
+    """
+
+    JOB_INTERMEDIATE_STATES = {'PENDING', 'RUNNING', 'SCHEDULED', 'SUBMITTED'}
+    JOB_FAILURE_STATES = {'FAILED', 'CANCELLING', 'CANCELLED'}
+    JOB_SUCCESS_STATES = {'SUCCESS'}
+    JOB_TERMINAL_STATES = JOB_SUCCESS_STATES.union(JOB_FAILURE_STATES)
+
+    APPLICATION_INTERMEDIATE_STATES = {'CREATING', 'STARTING', 'STOPPING'}
+    APPLICATION_FAILURE_STATES = {'STOPPED', 'TERMINATED'}
+    APPLICATION_SUCCESS_STATES = {'CREATED', 'STARTED'}
+
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        kwargs["client_type"] = "emr-serverless"
+        super().__init__(*args, **kwargs)
+
+    @cached_property
+    def conn(self):
+        """Get the underlying boto3 EmrServerlessAPIService client (cached)"""
+        return super().conn
+
+    # This method should be replaced with boto waiters which would implement timeouts and backoff nicely.
+    def waiter(
+        self,
+        get_state_callable: Callable,
+        get_state_args: dict,
+        parse_response: list,
+        desired_state: set,
+        failure_states: set,
+        object_type: str,
+        action: str,
+        countdown: int = 25 * 60,
+        check_interval_seconds: int = 60,
+    ) -> None:
+        """
+        Will run the sensor until it turns True.
+
+        :param get_state_callable: A callable to run until it returns True
+        :param get_state_args: Arguments to pass to get_state_callable
+        :param parse_response: Dictionary keys to extract state from response of get_state_callable
+        :param desired_state: Wait until the getter returns this value
+        :param failure_states: A set of states which indicate failure and should throw an
+            exception if any are reached before the desired_state
+        :param object_type: Used for the reporting string. What are you waiting for? (application, job, etc)
+        :param action: Used for the reporting string. What action are you waiting for? (created, deleted, etc)
+        :param countdown: Total amount of time the waiter should wait for the desired state
+            before timing out (in seconds). Defaults to 25 * 60 seconds.
+        :param check_interval_seconds: Number of seconds waiter should wait before attempting
+            to retry get_state_callable. Defaults to 60 seconds.
+        """
+        response = get_state_callable(**get_state_args)
+        state: str = self.get_state(response, parse_response)
+        while state not in desired_state:
+            if state in failure_states:
+                raise AirflowException(f'{object_type.title()} reached failure state {state}.')
+            if countdown >= check_interval_seconds:
+                countdown -= check_interval_seconds
+                self.log.info('Waiting for %s to be %s.', object_type.lower(), action.lower())
+                sleep(check_interval_seconds)
+                state = self.get_state(get_state_callable(**get_state_args), parse_response)
+            else:
+                message = f'{object_type.title()} still not {action.lower()} after the allocated time limit.'
+                self.log.error(message)
+                raise RuntimeError(message)
+
+    def get_state(self, response, keys) -> str:
+        value = response
+        for key in keys:
+            if value is not None:
+                value = value.get(key, None)
+        return value
+
+
 class EmrContainerHook(AwsBaseHook):
     """
     Interact with AWS EMR Virtual Cluster to run, poll jobs and return job status
@@ -120,19 +205,45 @@ class EmrContainerHook(AwsBaseHook):
         "CANCEL_PENDING",
     )
 
-    def __init__(self, *args: Any, virtual_cluster_id: Optional[str] = None, **kwargs: Any) -> None:
+    def __init__(self, *args: Any, virtual_cluster_id: str | None = None, **kwargs: Any) -> None:
         super().__init__(client_type="emr-containers", *args, **kwargs)  # type: ignore
         self.virtual_cluster_id = virtual_cluster_id
 
+    def create_emr_on_eks_cluster(
+        self,
+        virtual_cluster_name: str,
+        eks_cluster_name: str,
+        eks_namespace: str,
+        tags: dict | None = None,
+    ) -> str:
+        response = self.conn.create_virtual_cluster(
+            name=virtual_cluster_name,
+            containerProvider={
+                "id": eks_cluster_name,
+                "type": "EKS",
+                "info": {"eksInfo": {"namespace": eks_namespace}},
+            },
+            tags=tags or {},
+        )
+
+        if response['ResponseMetadata']['HTTPStatusCode'] != 200:
+            raise AirflowException(f'Create EMR EKS Cluster failed: {response}')
+        else:
+            self.log.info(
+                "Create EMR EKS Cluster success - virtual cluster id %s",
+                response['id'],
+            )
+            return response['id']
+
     def submit_job(
         self,
         name: str,
         execution_role_arn: str,
         release_label: str,
         job_driver: dict,
-        configuration_overrides: Optional[dict] = None,
-        client_request_token: Optional[str] = None,
-        tags: Optional[dict] = None,
+        configuration_overrides: dict | None = None,
+        client_request_token: str | None = None,
+        tags: dict | None = None,
     ) -> str:
         """
         Submit a job to the EMR Containers API and return the job ID.
@@ -175,7 +286,7 @@ class EmrContainerHook(AwsBaseHook):
             )
             return response['id']
 
-    def get_job_failure_reason(self, job_id: str) -> Optional[str]:
+    def get_job_failure_reason(self, job_id: str) -> str | None:
         """
         Fetch the reason for a job failure (e.g. error message). Returns None or reason string.
 
@@ -200,7 +311,7 @@ class EmrContainerHook(AwsBaseHook):
 
         return reason
 
-    def check_query_status(self, job_id: str) -> Optional[str]:
+    def check_query_status(self, job_id: str) -> str | None:
         """
         Fetch the status of submitted job run. Returns None or one of valid query states.
         See: https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-containers.html#EMRContainers.Client.describe_job_run  # noqa: E501
@@ -222,19 +333,36 @@ class EmrContainerHook(AwsBaseHook):
             return None
 
     def poll_query_status(
-        self, job_id: str, max_tries: Optional[int] = None, poll_interval: int = 30
-    ) -> Optional[str]:
+        self,
+        job_id: str,
+        max_tries: int | None = None,
+        poll_interval: int = 30,
+        max_polling_attempts: int | None = None,
+    ) -> str | None:
         """
         Poll the status of submitted job run until query state reaches final state.
         Returns one of the final states.
 
         :param job_id: Id of submitted job run
-        :param max_tries: Number of times to poll for query state before function exits
+        :param max_tries: Deprecated - Use max_polling_attempts instead
         :param poll_interval: Time (in seconds) to wait between calls to check query status on EMR
+        :param max_polling_attempts: Number of times to poll for query state before function exits
         :return: str
         """
+        if max_tries:
+            warnings.warn(
+                f"Method `{self.__class__.__name__}.max_tries` is deprecated and will be removed "
+                "in a future release.  Please use method `max_polling_attempts` instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+            if max_polling_attempts and max_polling_attempts != max_tries:
+                raise Exception("max_polling_attempts must be the same value as max_tries")
+            else:
+                max_polling_attempts = max_tries
+
         try_number = 1
-        final_query_state = None  # Query state when query reaches final state or max_tries reached
+        final_query_state = None  # Query state when query reaches final state or max_polling_attempts reached
 
         while True:
             query_state = self.check_query_status(job_id)
@@ -246,14 +374,16 @@ class EmrContainerHook(AwsBaseHook):
                 break
             else:
                 self.log.info("Try %s: Query is still in non-terminal state - %s", try_number, query_state)
-            if max_tries and try_number >= max_tries:  # Break loop if max_tries reached
+            if (
+                max_polling_attempts and try_number >= max_polling_attempts
+            ):  # Break loop if max_polling_attempts reached
                 final_query_state = query_state
                 break
             try_number += 1
             sleep(poll_interval)
         return final_query_state
 
-    def stop_query(self, job_id: str) -> Dict:
+    def stop_query(self, job_id: str) -> dict:
         """
         Cancel the submitted job_run
 
