@@ -14,21 +14,15 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
-import sys
-from typing import Dict, List, Optional, Union
+from __future__ import annotations
 
 import redshift_connector
 from redshift_connector import Connection as RedshiftConnection
 from sqlalchemy import create_engine
 from sqlalchemy.engine.url import URL
 
-from airflow.hooks.dbapi import DbApiHook
-
-if sys.version_info >= (3, 8):
-    from functools import cached_property
-else:
-    from cached_property import cached_property
+from airflow.compat.functools import cached_property
+from airflow.providers.common.sql.hooks.sql import DbApiHook
 
 
 class RedshiftSQLHook(DbApiHook):
@@ -39,7 +33,6 @@ class RedshiftSQLHook(DbApiHook):
 
     :param redshift_conn_id: reference to
         :ref:`Amazon Redshift connection id<howto/connection:redshift>`
-    :type redshift_conn_id: str
 
     .. note::
         get_sqlalchemy_engine() and get_uri() depend on sqlalchemy-amazon-redshift
@@ -52,7 +45,7 @@ class RedshiftSQLHook(DbApiHook):
     supports_autocommit = True
 
     @staticmethod
-    def get_ui_field_behavior() -> Dict:
+    def get_ui_field_behavior() -> dict:
         """Returns custom field behavior"""
         return {
             "hidden_fields": [],
@@ -63,11 +56,11 @@ class RedshiftSQLHook(DbApiHook):
     def conn(self):
         return self.get_connection(self.redshift_conn_id)  # type: ignore[attr-defined]
 
-    def _get_conn_params(self) -> Dict[str, Union[str, int]]:
+    def _get_conn_params(self) -> dict[str, str | int]:
         """Helper method to retrieve connection args"""
         conn = self.conn
 
-        conn_params: Dict[str, Union[str, int]] = {}
+        conn_params: dict[str, str | int] = {}
 
         if conn.login:
             conn_params['user'] = conn.login
@@ -104,13 +97,11 @@ class RedshiftSQLHook(DbApiHook):
 
         return create_engine(self.get_uri(), **engine_kwargs)
 
-    def get_table_primary_key(self, table: str, schema: Optional[str] = "public") -> Optional[List[str]]:
+    def get_table_primary_key(self, table: str, schema: str | None = "public") -> list[str] | None:
         """
         Helper method that returns the table primary key
         :param table: Name of the target table
-        :type table: str
         :param table: Name of the target schema, public by default
-        :type table: str
         :return: Primary key columns list
         :rtype: List[str]
         """
@@ -132,7 +123,5 @@ class RedshiftSQLHook(DbApiHook):
         """Returns a redshift_connector.Connection object"""
         conn_params = self._get_conn_params()
         conn_kwargs_dejson = self.conn.extra_dejson
-        conn_kwargs: Dict = {**conn_params, **conn_kwargs_dejson}
-        conn: RedshiftConnection = redshift_connector.connect(**conn_kwargs)
-
-        return conn
+        conn_kwargs: dict = {**conn_params, **conn_kwargs_dejson}
+        return redshift_connector.connect(**conn_kwargs)
