@@ -15,9 +15,9 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
-
 """Interact with AWS S3, using the boto3 library."""
+from __future__ import annotations
+
 import fnmatch
 import gzip as gz
 import io
@@ -30,7 +30,7 @@ from inspect import signature
 from io import BytesIO
 from pathlib import Path
 from tempfile import NamedTemporaryFile
-from typing import Any, Callable, Dict, List, Optional, Tuple, TypeVar, Union, cast
+from typing import Any, Callable, List, TypeVar, cast
 from urllib.parse import urlparse
 
 from boto3.s3.transfer import S3Transfer, TransferConfig
@@ -114,26 +114,23 @@ class S3Hook(AwsBaseHook):
         :class:`~airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
     """
 
-    conn_type = 's3'
-    hook_name = 'Amazon S3'
-
     def __init__(
         self,
-        aws_conn_id: Optional[str] = AwsBaseHook.default_conn_name,
-        transfer_config_args: Optional[Dict] = None,
-        extra_args: Optional[Dict] = None,
+        aws_conn_id: str | None = AwsBaseHook.default_conn_name,
+        transfer_config_args: dict | None = None,
+        extra_args: dict | None = None,
         *args,
         **kwargs,
     ) -> None:
         kwargs['client_type'] = 's3'
         kwargs['aws_conn_id'] = aws_conn_id
 
-        if extra_args and not isinstance(extra_args, dict):
-            raise ValueError(f"transfer_config_args '{extra_args!r}' must be of type {dict}")
+        if transfer_config_args and not isinstance(transfer_config_args, dict):
+            raise TypeError(f"transfer_config_args expected dict, got {type(transfer_config_args).__name__}.")
         self.transfer_config = TransferConfig(**transfer_config_args or {})
 
         if extra_args and not isinstance(extra_args, dict):
-            raise ValueError(f"extra_args '{extra_args!r}' must be of type {dict}")
+            raise TypeError(f"extra_args expected dict, got {type(extra_args).__name__}.")
         self._extra_args = extra_args or {}
 
         super().__init__(*args, **kwargs)
@@ -144,28 +141,41 @@ class S3Hook(AwsBaseHook):
         return deepcopy(self._extra_args)
 
     @staticmethod
-    def parse_s3_url(s3url: str) -> Tuple[str, str]:
+    def parse_s3_url(s3url: str) -> tuple[str, str]:
         """
         Parses the S3 Url into a bucket name and key.
+            See https://docs.aws.amazon.com/AmazonS3/latest/userguide/access-bucket-intro.html
+            for valid url formats
 
         :param s3url: The S3 Url to parse.
         :return: the parsed bucket name and key
         :rtype: tuple of str
         """
-        parsed_url = urlparse(s3url)
-
-        if not parsed_url.netloc:
-            raise AirflowException(f'Please provide a bucket_name instead of "{s3url}"')
-
-        bucket_name = parsed_url.netloc
-        key = parsed_url.path.lstrip('/')
+        format = s3url.split('//')
+        if format[0].lower() == 's3:':
+            parsed_url = urlparse(s3url)
+            if not parsed_url.netloc:
+                raise AirflowException(f'Please provide a bucket name using a valid format: "{s3url}"')
 
+            bucket_name = parsed_url.netloc
+            key = parsed_url.path.lstrip('/')
+        elif format[0] == 'https:':
+            temp_split = format[1].split('.')
+            if temp_split[0] == 's3':
+                split_url = format[1].split('/')
+                bucket_name = split_url[1]
+                key = '/'.join(split_url[2:])
+            elif temp_split[1] == 's3':
+                bucket_name = temp_split[0]
+                key = '/'.join(format[1].split('/')[1:])
+        else:
+            raise AirflowException(f'Please provide a bucket name using a valid format: "{s3url}"')
         return bucket_name, key
 
     @staticmethod
     def get_s3_bucket_key(
-        bucket: Optional[str], key: str, bucket_param_name: str, key_param_name: str
-    ) -> Tuple[str, str]:
+        bucket: str | None, key: str, bucket_param_name: str, key_param_name: str
+    ) -> tuple[str, str]:
         """
         Get the S3 bucket name and key from either:
             - bucket name and key. Return the info as it is after checking `key` is a relative path
@@ -191,7 +201,7 @@ class S3Hook(AwsBaseHook):
         return bucket, key
 
     @provide_bucket_name
-    def check_for_bucket(self, bucket_name: Optional[str] = None) -> bool:
+    def check_for_bucket(self, bucket_name: str | None = None) -> bool:
         """
         Check if bucket_name exists.
 
@@ -203,11 +213,23 @@ class S3Hook(AwsBaseHook):
             self.get_conn().head_bucket(Bucket=bucket_name)
             return True
         except ClientError as e:
-            self.log.error(e.response["Error"]["Message"])
+            # The head_bucket api is odd in that it cannot return proper
+            # exception objects, so error codes must be used. Only 200, 404 and 403
+            # are ever returned. See the following links for more details:
+            # https://github.com/boto/boto3/issues/2499
+            # https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3.html#S3.Client.head_bucket
+            return_code = int(e.response['Error']['Code'])
+            if return_code == 404:
+                self.log.error('Bucket "%s" does not exist', bucket_name)
+            elif return_code == 403:
+                self.log.error(
+                    'Access to bucket "%s" is forbidden or there was an error with the request', bucket_name
+                )
+                self.log.error(e)
             return False
 
     @provide_bucket_name
-    def get_bucket(self, bucket_name: Optional[str] = None) -> object:
+    def get_bucket(self, bucket_name: str | None = None) -> object:
         """
         Returns a boto3.S3.Bucket object
 
@@ -215,19 +237,16 @@ class S3Hook(AwsBaseHook):
         :return: the bucket object to the bucket name.
         :rtype: boto3.S3.Bucket
         """
-        # Buckets have no regions, and we cannot remove the region name from _get_credentials as we would
-        # break compatibility, so we set it explicitly to None.
-        session, endpoint_url = self._get_credentials(region_name=None)
-        s3_resource = session.resource(
+        s3_resource = self.get_session().resource(
             "s3",
-            endpoint_url=endpoint_url,
+            endpoint_url=self.conn_config.endpoint_url,
             config=self.config,
             verify=self.verify,
         )
         return s3_resource.Bucket(bucket_name)
 
     @provide_bucket_name
-    def create_bucket(self, bucket_name: Optional[str] = None, region_name: Optional[str] = None) -> None:
+    def create_bucket(self, bucket_name: str | None = None, region_name: str | None = None) -> None:
         """
         Creates an Amazon S3 bucket.
 
@@ -235,7 +254,13 @@ class S3Hook(AwsBaseHook):
         :param region_name: The name of the aws region in which to create the bucket.
         """
         if not region_name:
-            region_name = self.get_conn().meta.region_name
+            if self.conn_region_name == "aws-global":
+                raise AirflowException(
+                    "Unable to create bucket if `region_name` not set "
+                    "and boto3 configured to use s3 regional endpoints."
+                )
+            region_name = self.conn_region_name
+
         if region_name == 'us-east-1':
             self.get_conn().create_bucket(Bucket=bucket_name)
         else:
@@ -244,7 +269,7 @@ class S3Hook(AwsBaseHook):
             )
 
     @provide_bucket_name
-    def check_for_prefix(self, prefix: str, delimiter: str, bucket_name: Optional[str] = None) -> bool:
+    def check_for_prefix(self, prefix: str, delimiter: str, bucket_name: str | None = None) -> bool:
         """
         Checks that a prefix exists in a bucket
 
@@ -263,11 +288,11 @@ class S3Hook(AwsBaseHook):
     @provide_bucket_name
     def list_prefixes(
         self,
-        bucket_name: Optional[str] = None,
-        prefix: Optional[str] = None,
-        delimiter: Optional[str] = None,
-        page_size: Optional[int] = None,
-        max_items: Optional[int] = None,
+        bucket_name: str | None = None,
+        prefix: str | None = None,
+        delimiter: str | None = None,
+        page_size: int | None = None,
+        max_items: int | None = None,
     ) -> list:
         """
         Lists prefixes in a bucket under prefix
@@ -300,7 +325,7 @@ class S3Hook(AwsBaseHook):
         return prefixes
 
     def _list_key_object_filter(
-        self, keys: list, from_datetime: Optional[datetime] = None, to_datetime: Optional[datetime] = None
+        self, keys: list, from_datetime: datetime | None = None, to_datetime: datetime | None = None
     ) -> list:
         def _is_in_period(input_date: datetime) -> bool:
             if from_datetime is not None and input_date <= from_datetime:
@@ -314,15 +339,15 @@ class S3Hook(AwsBaseHook):
     @provide_bucket_name
     def list_keys(
         self,
-        bucket_name: Optional[str] = None,
-        prefix: Optional[str] = None,
-        delimiter: Optional[str] = None,
-        page_size: Optional[int] = None,
-        max_items: Optional[int] = None,
-        start_after_key: Optional[str] = None,
-        from_datetime: Optional[datetime] = None,
-        to_datetime: Optional[datetime] = None,
-        object_filter: Optional[Callable[..., list]] = None,
+        bucket_name: str | None = None,
+        prefix: str | None = None,
+        delimiter: str | None = None,
+        page_size: int | None = None,
+        max_items: int | None = None,
+        start_after_key: str | None = None,
+        from_datetime: datetime | None = None,
+        to_datetime: datetime | None = None,
+        object_filter: Callable[..., list] | None = None,
     ) -> list:
         """
         Lists keys in a bucket under prefix and not containing delimiter
@@ -393,10 +418,10 @@ class S3Hook(AwsBaseHook):
     def get_file_metadata(
         self,
         prefix: str,
-        bucket_name: Optional[str] = None,
-        page_size: Optional[int] = None,
-        max_items: Optional[int] = None,
-    ) -> List:
+        bucket_name: str | None = None,
+        page_size: int | None = None,
+        max_items: int | None = None,
+    ) -> list:
         """
         Lists metadata objects in a bucket under prefix
 
@@ -423,7 +448,7 @@ class S3Hook(AwsBaseHook):
 
     @provide_bucket_name
     @unify_bucket_name_and_key
-    def head_object(self, key: str, bucket_name: Optional[str] = None) -> Optional[dict]:
+    def head_object(self, key: str, bucket_name: str | None = None) -> dict | None:
         """
         Retrieves metadata of an object
 
@@ -442,7 +467,7 @@ class S3Hook(AwsBaseHook):
 
     @provide_bucket_name
     @unify_bucket_name_and_key
-    def check_for_key(self, key: str, bucket_name: Optional[str] = None) -> bool:
+    def check_for_key(self, key: str, bucket_name: str | None = None) -> bool:
         """
         Checks if a key exists in a bucket
 
@@ -456,7 +481,7 @@ class S3Hook(AwsBaseHook):
 
     @provide_bucket_name
     @unify_bucket_name_and_key
-    def get_key(self, key: str, bucket_name: Optional[str] = None) -> S3Transfer:
+    def get_key(self, key: str, bucket_name: str | None = None) -> S3Transfer:
         """
         Returns a boto3.s3.Object
 
@@ -465,12 +490,9 @@ class S3Hook(AwsBaseHook):
         :return: the key object from the bucket
         :rtype: boto3.s3.Object
         """
-        # Buckets have no regions, and we cannot remove the region name from _get_credentials as we would
-        # break compatibility, so we set it explicitly to None.
-        session, endpoint_url = self._get_credentials(region_name=None)
-        s3_resource = session.resource(
+        s3_resource = self.get_session().resource(
             "s3",
-            endpoint_url=endpoint_url,
+            endpoint_url=self.conn_config.endpoint_url,
             config=self.config,
             verify=self.verify,
         )
@@ -480,7 +502,7 @@ class S3Hook(AwsBaseHook):
 
     @provide_bucket_name
     @unify_bucket_name_and_key
-    def read_key(self, key: str, bucket_name: Optional[str] = None) -> str:
+    def read_key(self, key: str, bucket_name: str | None = None) -> str:
         """
         Reads a key from S3
 
@@ -497,11 +519,11 @@ class S3Hook(AwsBaseHook):
     def select_key(
         self,
         key: str,
-        bucket_name: Optional[str] = None,
-        expression: Optional[str] = None,
-        expression_type: Optional[str] = None,
-        input_serialization: Optional[Dict[str, Any]] = None,
-        output_serialization: Optional[Dict[str, Any]] = None,
+        bucket_name: str | None = None,
+        expression: str | None = None,
+        expression_type: str | None = None,
+        input_serialization: dict[str, Any] | None = None,
+        output_serialization: dict[str, Any] | None = None,
     ) -> str:
         """
         Reads a key with S3 Select.
@@ -517,7 +539,7 @@ class S3Hook(AwsBaseHook):
 
         .. seealso::
             For more details about S3 Select parameters:
-            http://boto3.readthedocs.io/en/latest/reference/services/s3.html#S3.Client.select_object_content
+            https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3.html#S3.Client.select_object_content
         """
         expression = expression or 'SELECT * FROM S3Object'
         expression_type = expression_type or 'SQL'
@@ -543,7 +565,7 @@ class S3Hook(AwsBaseHook):
     @provide_bucket_name
     @unify_bucket_name_and_key
     def check_for_wildcard_key(
-        self, wildcard_key: str, bucket_name: Optional[str] = None, delimiter: str = ''
+        self, wildcard_key: str, bucket_name: str | None = None, delimiter: str = ''
     ) -> bool:
         """
         Checks that a key matching a wildcard expression exists in a bucket
@@ -562,7 +584,7 @@ class S3Hook(AwsBaseHook):
     @provide_bucket_name
     @unify_bucket_name_and_key
     def get_wildcard_key(
-        self, wildcard_key: str, bucket_name: Optional[str] = None, delimiter: str = ''
+        self, wildcard_key: str, bucket_name: str | None = None, delimiter: str = ''
     ) -> S3Transfer:
         """
         Returns a boto3.s3.Object object matching the wildcard expression
@@ -584,13 +606,13 @@ class S3Hook(AwsBaseHook):
     @unify_bucket_name_and_key
     def load_file(
         self,
-        filename: Union[Path, str],
+        filename: Path | str,
         key: str,
-        bucket_name: Optional[str] = None,
+        bucket_name: str | None = None,
         replace: bool = False,
         encrypt: bool = False,
         gzip: bool = False,
-        acl_policy: Optional[str] = None,
+        acl_policy: str | None = None,
     ) -> None:
         """
         Loads a local file to S3
@@ -632,12 +654,12 @@ class S3Hook(AwsBaseHook):
         self,
         string_data: str,
         key: str,
-        bucket_name: Optional[str] = None,
+        bucket_name: str | None = None,
         replace: bool = False,
         encrypt: bool = False,
-        encoding: Optional[str] = None,
-        acl_policy: Optional[str] = None,
-        compression: Optional[str] = None,
+        encoding: str | None = None,
+        acl_policy: str | None = None,
+        compression: str | None = None,
     ) -> None:
         """
         Loads a string to S3
@@ -682,10 +704,10 @@ class S3Hook(AwsBaseHook):
         self,
         bytes_data: bytes,
         key: str,
-        bucket_name: Optional[str] = None,
+        bucket_name: str | None = None,
         replace: bool = False,
         encrypt: bool = False,
-        acl_policy: Optional[str] = None,
+        acl_policy: str | None = None,
     ) -> None:
         """
         Loads bytes to S3
@@ -713,10 +735,10 @@ class S3Hook(AwsBaseHook):
         self,
         file_obj: BytesIO,
         key: str,
-        bucket_name: Optional[str] = None,
+        bucket_name: str | None = None,
         replace: bool = False,
         encrypt: bool = False,
-        acl_policy: Optional[str] = None,
+        acl_policy: str | None = None,
     ) -> None:
         """
         Loads a file object to S3
@@ -737,10 +759,10 @@ class S3Hook(AwsBaseHook):
         self,
         file_obj: BytesIO,
         key: str,
-        bucket_name: Optional[str] = None,
+        bucket_name: str | None = None,
         replace: bool = False,
         encrypt: bool = False,
-        acl_policy: Optional[str] = None,
+        acl_policy: str | None = None,
     ) -> None:
         if not replace and self.check_for_key(key, bucket_name):
             raise ValueError(f"The key {key} already exists.")
@@ -764,10 +786,10 @@ class S3Hook(AwsBaseHook):
         self,
         source_bucket_key: str,
         dest_bucket_key: str,
-        source_bucket_name: Optional[str] = None,
-        dest_bucket_name: Optional[str] = None,
-        source_version_id: Optional[str] = None,
-        acl_policy: Optional[str] = None,
+        source_bucket_name: str | None = None,
+        dest_bucket_name: str | None = None,
+        source_version_id: str | None = None,
+        acl_policy: str | None = None,
     ) -> None:
         """
         Creates a copy of an object that is already stored in S3.
@@ -826,7 +848,7 @@ class S3Hook(AwsBaseHook):
                 self.delete_objects(bucket=bucket_name, keys=bucket_keys)
         self.conn.delete_bucket(Bucket=bucket_name)
 
-    def delete_objects(self, bucket: str, keys: Union[str, list]) -> None:
+    def delete_objects(self, bucket: str, keys: str | list) -> None:
         """
         Delete keys from the bucket.
 
@@ -857,9 +879,7 @@ class S3Hook(AwsBaseHook):
 
     @provide_bucket_name
     @unify_bucket_name_and_key
-    def download_file(
-        self, key: str, bucket_name: Optional[str] = None, local_path: Optional[str] = None
-    ) -> str:
+    def download_file(self, key: str, bucket_name: str | None = None, local_path: str | None = None) -> str:
         """
         Downloads a file from the S3 location to the local file system.
 
@@ -894,10 +914,10 @@ class S3Hook(AwsBaseHook):
     def generate_presigned_url(
         self,
         client_method: str,
-        params: Optional[dict] = None,
+        params: dict | None = None,
         expires_in: int = 3600,
-        http_method: Optional[str] = None,
-    ) -> Optional[str]:
+        http_method: str | None = None,
+    ) -> str | None:
         """
         Generate a presigned url given a client, its method, and arguments
 
@@ -921,7 +941,7 @@ class S3Hook(AwsBaseHook):
             return None
 
     @provide_bucket_name
-    def get_bucket_tagging(self, bucket_name: Optional[str] = None) -> Optional[List[Dict[str, str]]]:
+    def get_bucket_tagging(self, bucket_name: str | None = None) -> list[dict[str, str]] | None:
         """
         Gets a List of tags from a bucket.
 
@@ -941,10 +961,10 @@ class S3Hook(AwsBaseHook):
     @provide_bucket_name
     def put_bucket_tagging(
         self,
-        tag_set: Optional[List[Dict[str, str]]] = None,
-        key: Optional[str] = None,
-        value: Optional[str] = None,
-        bucket_name: Optional[str] = None,
+        tag_set: list[dict[str, str]] | None = None,
+        key: str | None = None,
+        value: str | None = None,
+        bucket_name: str | None = None,
     ) -> None:
         """
         Overwrites the existing TagSet with provided tags.  Must provide either a TagSet or a key/value pair.
@@ -974,7 +994,7 @@ class S3Hook(AwsBaseHook):
             raise e
 
     @provide_bucket_name
-    def delete_bucket_tagging(self, bucket_name: Optional[str] = None) -> None:
+    def delete_bucket_tagging(self, bucket_name: str | None = None) -> None:
         """
         Deletes all tags from a bucket.
 
