@@ -15,15 +15,16 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
+
 import collections
 import os
 import tarfile
 import tempfile
 import time
-import warnings
 from datetime import datetime
 from functools import partial
-from typing import Any, Callable, Dict, Generator, List, Optional, Set, cast
+from typing import Any, Callable, Generator, cast
 
 from botocore.exceptions import ClientError
 
@@ -52,7 +53,7 @@ class LogState:
 Position = collections.namedtuple('Position', ['timestamp', 'skip'])
 
 
-def argmin(arr, f: Callable) -> Optional[int]:
+def argmin(arr, f: Callable) -> int | None:
     """Return the index, i, in arr that minimizes f(arr[i])"""
     min_value = None
     min_idx = None
@@ -94,7 +95,7 @@ def secondary_training_status_changed(current_job_description: dict, prev_job_de
 
 
 def secondary_training_status_message(
-    job_description: Dict[str, List[Any]], prev_description: Optional[dict]
+    job_description: dict[str, list[Any]], prev_description: dict | None
 ) -> str:
     """
     Returns a string contains start time and the secondary training job status message.
@@ -236,36 +237,6 @@ class SageMakerHook(AwsBaseHook):
             if "S3DataSource" in channel['DataSource']:
                 self.check_s3_url(channel['DataSource']['S3DataSource']['S3Uri'])
 
-    def get_log_conn(self):
-        """
-        This method is deprecated.
-        Please use :py:meth:`airflow.providers.amazon.aws.hooks.logs.AwsLogsHook.get_conn` instead.
-        """
-        warnings.warn(
-            "Method `get_log_conn` has been deprecated. "
-            "Please use `airflow.providers.amazon.aws.hooks.logs.AwsLogsHook.get_conn` instead.",
-            category=DeprecationWarning,
-            stacklevel=2,
-        )
-
-        return self.logs_hook.get_conn()
-
-    def log_stream(self, log_group, stream_name, start_time=0, skip=0):
-        """
-        This method is deprecated.
-        Please use
-        :py:meth:`airflow.providers.amazon.aws.hooks.logs.AwsLogsHook.get_log_events` instead.
-        """
-        warnings.warn(
-            "Method `log_stream` has been deprecated. "
-            "Please use "
-            "`airflow.providers.amazon.aws.hooks.logs.AwsLogsHook.get_log_events` instead.",
-            category=DeprecationWarning,
-            stacklevel=2,
-        )
-
-        return self.logs_hook.get_log_events(log_group, stream_name, start_time, skip)
-
     def multi_stream_iter(self, log_group: str, streams: list, positions=None) -> Generator:
         """
         Iterate over the available events coming from a set of log streams in a single log group
@@ -283,7 +254,7 @@ class SageMakerHook(AwsBaseHook):
             self.logs_hook.get_log_events(log_group, s, positions[s].timestamp, positions[s].skip)
             for s in streams
         ]
-        events: List[Optional[Any]] = []
+        events: list[Any | None] = []
         for event_stream in event_iters:
             if not event_stream:
                 events.append(None)
@@ -307,10 +278,11 @@ class SageMakerHook(AwsBaseHook):
         wait_for_completion: bool = True,
         print_log: bool = True,
         check_interval: int = 30,
-        max_ingestion_time: Optional[int] = None,
+        max_ingestion_time: int | None = None,
     ):
         """
-        Create a training job
+        Starts a model training job. After training completes, Amazon SageMaker saves
+        the resulting model artifacts to an Amazon S3 location that you specify.
 
         :param config: the config for training
         :param wait_for_completion: if the program should keep running until job finishes
@@ -354,10 +326,14 @@ class SageMakerHook(AwsBaseHook):
         config: dict,
         wait_for_completion: bool = True,
         check_interval: int = 30,
-        max_ingestion_time: Optional[int] = None,
+        max_ingestion_time: int | None = None,
     ):
         """
-        Create a tuning job
+        Starts a hyperparameter tuning job. A hyperparameter tuning job finds the
+        best version of a model by running many training jobs on your dataset using
+        the algorithm you choose and values for hyperparameters within ranges that
+        you specify. It then chooses the hyperparameter values that result in a model
+        that performs the best, as measured by an objective metric that you choose.
 
         :param config: the config for tuning
         :param wait_for_completion: if the program should keep running until job finishes
@@ -386,10 +362,11 @@ class SageMakerHook(AwsBaseHook):
         config: dict,
         wait_for_completion: bool = True,
         check_interval: int = 30,
-        max_ingestion_time: Optional[int] = None,
+        max_ingestion_time: int | None = None,
     ):
         """
-        Create a transform job
+        Starts a transform job. A transform job uses a trained model to get inferences
+        on a dataset and saves these results to an Amazon S3 location that you specify.
 
         :param config: the config for transform job
         :param wait_for_completion: if the program should keep running until job finishes
@@ -419,10 +396,13 @@ class SageMakerHook(AwsBaseHook):
         config: dict,
         wait_for_completion: bool = True,
         check_interval: int = 30,
-        max_ingestion_time: Optional[int] = None,
+        max_ingestion_time: int | None = None,
     ):
         """
-        Create a processing job
+        Use Amazon SageMaker Processing to analyze data and evaluate machine learning
+        models on Amazon SageMaker. With Processing, you can use a simplified, managed
+        experience on SageMaker to run your data processing workloads, such as feature
+        engineering, data validation, model evaluation, and model interpretation.
 
         :param config: the config for processing job
         :param wait_for_completion: if the program should keep running until job finishes
@@ -446,7 +426,10 @@ class SageMakerHook(AwsBaseHook):
 
     def create_model(self, config: dict):
         """
-        Create a model job
+        Creates a model in Amazon SageMaker. In the request, you name the model and
+        describe a primary container. For the primary container, you specify the Docker
+        image that contains inference code, artifacts (from prior training), and a custom
+        environment map that the inference code uses when you deploy the model for predictions.
 
         :param config: the config for model
         :return: A response to model creation
@@ -455,7 +438,14 @@ class SageMakerHook(AwsBaseHook):
 
     def create_endpoint_config(self, config: dict):
         """
-        Create an endpoint config
+        Creates an endpoint configuration that Amazon SageMaker hosting
+        services uses to deploy models. In the configuration, you identify
+        one or more models, created using the CreateModel API, to deploy and
+        the resources that you want Amazon SageMaker to provision.
+
+        .. seealso::
+             :class:`~airflow.providers.amazon.aws.hooks.sagemaker.SageMakerHook.create_model`
+             :class:`~airflow.providers.amazon.aws.hooks.sagemaker.SageMakerHook.create_endpoint`
 
         :param config: the config for endpoint-config
         :return: A response to endpoint config creation
@@ -467,10 +457,18 @@ class SageMakerHook(AwsBaseHook):
         config: dict,
         wait_for_completion: bool = True,
         check_interval: int = 30,
-        max_ingestion_time: Optional[int] = None,
+        max_ingestion_time: int | None = None,
     ):
         """
-        Create an endpoint
+        When you create a serverless endpoint, SageMaker provisions and manages
+        the compute resources for you. Then, you can make inference requests to
+        the endpoint and receive model predictions in response. SageMaker scales
+        the compute resources up and down as needed to handle your request traffic.
+
+        Requires an Endpoint Config.
+         .. seealso::
+             :class:`~airflow.providers.amazon.aws.hooks.sagemaker.SageMakerHook.create_endpoint_config`
+
 
         :param config: the config for endpoint
         :param wait_for_completion: if the program should keep running until job finishes
@@ -498,10 +496,12 @@ class SageMakerHook(AwsBaseHook):
         config: dict,
         wait_for_completion: bool = True,
         check_interval: int = 30,
-        max_ingestion_time: Optional[int] = None,
+        max_ingestion_time: int | None = None,
     ):
         """
-        Update an endpoint
+        Deploys the new EndpointConfig specified in the request, switches to using
+        newly created endpoint, and then deletes resources provisioned for the
+        endpoint using the previous EndpointConfig (there is no availability loss).
 
         :param config: the config for endpoint
         :param wait_for_completion: if the program should keep running until job finishes
@@ -652,8 +652,8 @@ class SageMakerHook(AwsBaseHook):
         key: str,
         describe_function: Callable,
         check_interval: int,
-        max_ingestion_time: Optional[int] = None,
-        non_terminal_states: Optional[Set] = None,
+        max_ingestion_time: int | None = None,
+        non_terminal_states: set | None = None,
     ):
         """
         Check status of a SageMaker job
@@ -712,7 +712,7 @@ class SageMakerHook(AwsBaseHook):
         failed_states: set,
         wait_for_completion: bool,
         check_interval: int,
-        max_ingestion_time: Optional[int] = None,
+        max_ingestion_time: int | None = None,
     ):
         """
         Display the logs for a given training job, optionally tailing them until the
@@ -796,8 +796,8 @@ class SageMakerHook(AwsBaseHook):
             self.log.info('Billable seconds: %d', int(billable_time.total_seconds()) + 1)
 
     def list_training_jobs(
-        self, name_contains: Optional[str] = None, max_results: Optional[int] = None, **kwargs
-    ) -> List[Dict]:
+        self, name_contains: str | None = None, max_results: int | None = None, **kwargs
+    ) -> list[dict]:
         """
         This method wraps boto3's `list_training_jobs`. The training job name and max results are configurable
         via arguments. Other arguments are not, and should be provided via kwargs. Note boto3 expects these in
@@ -815,28 +815,42 @@ class SageMakerHook(AwsBaseHook):
         :param kwargs: (optional) kwargs to boto3's list_training_jobs method
         :return: results of the list_training_jobs request
         """
-        config = {}
-
-        if name_contains:
-            if "NameContains" in kwargs:
-                raise AirflowException("Either name_contains or NameContains can be provided, not both.")
-            config["NameContains"] = name_contains
-
-        if "MaxResults" in kwargs and kwargs["MaxResults"] is not None:
-            if max_results:
-                raise AirflowException("Either max_results or MaxResults can be provided, not both.")
-            # Unset MaxResults, we'll use the SageMakerHook's internal method for iteratively fetching results
-            max_results = kwargs["MaxResults"]
-            del kwargs["MaxResults"]
-
-        config.update(kwargs)
+        config, max_results = self._preprocess_list_request_args(name_contains, max_results, **kwargs)
         list_training_jobs_request = partial(self.get_conn().list_training_jobs, **config)
         results = self._list_request(
             list_training_jobs_request, "TrainingJobSummaries", max_results=max_results
         )
         return results
 
-    def list_processing_jobs(self, **kwargs) -> List[Dict]:
+    def list_transform_jobs(
+        self, name_contains: str | None = None, max_results: int | None = None, **kwargs
+    ) -> list[dict]:
+        """
+        This method wraps boto3's `list_transform_jobs`.
+        The transform job name and max results are configurable via arguments.
+        Other arguments are not, and should be provided via kwargs. Note boto3 expects these in
+        CamelCase format, for example:
+
+        .. code-block:: python
+
+            list_transform_jobs(name_contains="myjob", StatusEquals="Failed")
+
+        .. seealso::
+            https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker.html#SageMaker.Client.list_transform_jobs
+
+        :param name_contains: (optional) partial name to match
+        :param max_results: (optional) maximum number of results to return. None returns infinite results
+        :param kwargs: (optional) kwargs to boto3's list_transform_jobs method
+        :return: results of the list_transform_jobs request
+        """
+        config, max_results = self._preprocess_list_request_args(name_contains, max_results, **kwargs)
+        list_transform_jobs_request = partial(self.get_conn().list_transform_jobs, **config)
+        results = self._list_request(
+            list_transform_jobs_request, "TransformJobSummaries", max_results=max_results
+        )
+        return results
+
+    def list_processing_jobs(self, **kwargs) -> list[dict]:
         """
         This method wraps boto3's `list_processing_jobs`. All arguments should be provided via kwargs.
         Note boto3 expects these in CamelCase format, for example:
@@ -857,9 +871,40 @@ class SageMakerHook(AwsBaseHook):
         )
         return results
 
+    def _preprocess_list_request_args(
+        self, name_contains: str | None = None, max_results: int | None = None, **kwargs
+    ) -> tuple[dict[str, Any], int | None]:
+        """
+        This method preprocesses the arguments to the boto3's list_* methods.
+        It will turn arguments name_contains and max_results as boto3 compliant CamelCase format.
+        This method also makes sure that these two arguments are only set once.
+
+        :param name_contains: boto3 function with arguments
+        :param max_results: the result key to iterate over
+        :param kwargs: (optional) kwargs to boto3's list_* method
+        :return: Tuple with config dict to be passed to boto3's list_* method and max_results parameter
+        """
+        config = {}
+
+        if name_contains:
+            if "NameContains" in kwargs:
+                raise AirflowException("Either name_contains or NameContains can be provided, not both.")
+            config["NameContains"] = name_contains
+
+        if "MaxResults" in kwargs and kwargs["MaxResults"] is not None:
+            if max_results:
+                raise AirflowException("Either max_results or MaxResults can be provided, not both.")
+            # Unset MaxResults, we'll use the SageMakerHook's internal method for iteratively fetching results
+            max_results = kwargs["MaxResults"]
+            del kwargs["MaxResults"]
+
+        config.update(kwargs)
+
+        return config, max_results
+
     def _list_request(
-        self, partial_func: Callable, result_key: str, max_results: Optional[int] = None
-    ) -> List[Dict]:
+        self, partial_func: Callable, result_key: str, max_results: int | None = None
+    ) -> list[dict]:
         """
         All AWS boto3 list_* requests return results in batches (if the key "NextToken" is contained in the
         result, there are more results to fetch). The default AWS batch size is 10, and configurable up to
@@ -876,7 +921,7 @@ class SageMakerHook(AwsBaseHook):
         """
         sagemaker_max_results = 100  # Fixed number set by AWS
 
-        results: List[Dict] = []
+        results: list[dict] = []
         next_token = None
 
         while True:
