@@ -15,9 +15,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
+from __future__ import annotations
+
 import warnings
-from typing import TYPE_CHECKING, Any, Dict, Optional, Sequence
+from typing import TYPE_CHECKING, Any, Optional, Sequence
 
 from airflow.compat.functools import cached_property
 from airflow.models import BaseOperator
@@ -44,7 +45,9 @@ class AthenaOperator(BaseOperator):
     :param query_execution_context: Context in which query need to be run
     :param result_configuration: Dict with path to store results in and config related to encryption
     :param sleep_time: Time (in seconds) to wait between two consecutive calls to check query status on Athena
-    :param max_tries: Number of times to poll for query state before function exits
+    :param max_tries: Deprecated - use max_polling_attempts instead.
+    :param max_polling_attempts: Number of times to poll for query state before function exits
+        To limit task execution time, use execution_timeout.
     """
 
     ui_color = '#44b5e2'
@@ -59,12 +62,13 @@ class AthenaOperator(BaseOperator):
         database: str,
         output_location: str,
         aws_conn_id: str = "aws_default",
-        client_request_token: Optional[str] = None,
+        client_request_token: str | None = None,
         workgroup: str = "primary",
-        query_execution_context: Optional[Dict[str, str]] = None,
-        result_configuration: Optional[Dict[str, Any]] = None,
+        query_execution_context: dict[str, str] | None = None,
+        result_configuration: dict[str, Any] | None = None,
         sleep_time: int = 30,
-        max_tries: Optional[int] = None,
+        max_tries: int | None = None,
+        max_polling_attempts: int | None = None,
         **kwargs: Any,
     ) -> None:
         super().__init__(**kwargs)
@@ -77,15 +81,27 @@ class AthenaOperator(BaseOperator):
         self.query_execution_context = query_execution_context or {}
         self.result_configuration = result_configuration or {}
         self.sleep_time = sleep_time
-        self.max_tries = max_tries
+        self.max_polling_attempts = max_polling_attempts
         self.query_execution_id = None  # type: Optional[str]
 
+        if max_tries:
+            warnings.warn(
+                f"Parameter `{self.__class__.__name__}.max_tries` is deprecated and will be removed "
+                "in a future release.  Please use method `max_polling_attempts` instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+            if max_polling_attempts and max_polling_attempts != max_tries:
+                raise Exception("max_polling_attempts must be the same value as max_tries")
+            else:
+                self.max_polling_attempts = max_tries
+
     @cached_property
     def hook(self) -> AthenaHook:
         """Create and return an AthenaHook."""
         return AthenaHook(self.aws_conn_id, sleep_time=self.sleep_time)
 
-    def execute(self, context: 'Context') -> Optional[str]:
+    def execute(self, context: Context) -> str | None:
         """Run Presto Query on Athena"""
         self.query_execution_context['Database'] = self.database
         self.result_configuration['OutputLocation'] = self.output_location
@@ -96,7 +112,7 @@ class AthenaOperator(BaseOperator):
             self.client_request_token,
             self.workgroup,
         )
-        query_status = self.hook.poll_query_status(self.query_execution_id, self.max_tries)
+        query_status = self.hook.poll_query_status(self.query_execution_id, self.max_polling_attempts)
 
         if query_status in AthenaHook.FAILURE_STATES:
             error_message = self.hook.get_state_change_reason(self.query_execution_id)
@@ -131,19 +147,3 @@ class AthenaOperator(BaseOperator):
                         'Polling Athena for query with id %s to reach final state', self.query_execution_id
                     )
                     self.hook.poll_query_status(self.query_execution_id)
-
-
-class AWSAthenaOperator(AthenaOperator):
-    """
-    This operator is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.operators.athena.AthenaOperator`.
-    """
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This operator is deprecated. Please use "
-            "`airflow.providers.amazon.aws.operators.athena.AthenaOperator`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        super().__init__(*args, **kwargs)
