@@ -14,20 +14,27 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
-
 """
 An Airflow operator for AWS Batch services
 
 .. seealso::
 
-    - http://boto3.readthedocs.io/en/latest/guide/configuration.html
-    - http://boto3.readthedocs.io/en/latest/reference/services/batch.html
+    - https://boto3.amazonaws.com/v1/documentation/api/latest/guide/configuration.html
+    - https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/batch.html
     - https://docs.aws.amazon.com/batch/latest/APIReference/Welcome.html
 """
-import warnings
+from __future__ import annotations
+
+import sys
 from typing import TYPE_CHECKING, Any, Optional, Sequence
 
+from airflow.providers.amazon.aws.utils import trim_none_values
+
+if sys.version_info >= (3, 8):
+    from functools import cached_property
+else:
+    from cached_property import cached_property
+
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.batch_client import BatchClientHook
@@ -96,6 +103,8 @@ class BatchOperator(BaseOperator):
     arn = None  # type: Optional[str]
     template_fields: Sequence[str] = (
         "job_name",
+        "job_queue",
+        "job_definition",
         "overrides",
         "parameters",
     )
@@ -103,7 +112,9 @@ class BatchOperator(BaseOperator):
 
     @property
     def operator_extra_links(self):
-        op_extra_links = [BatchJobDetailsLink(), BatchJobDefinitionLink(), BatchJobQueueLink()]
+        op_extra_links = [BatchJobDetailsLink()]
+        if self.wait_for_completion:
+            op_extra_links.extend([BatchJobDefinitionLink(), BatchJobQueueLink()])
         if not self.array_properties:
             # There is no CloudWatch Link to the parent Batch Job available.
             op_extra_links.append(CloudWatchEventsLink())
@@ -117,15 +128,16 @@ class BatchOperator(BaseOperator):
         job_definition: str,
         job_queue: str,
         overrides: dict,
-        array_properties: Optional[dict] = None,
-        parameters: Optional[dict] = None,
-        job_id: Optional[str] = None,
-        waiters: Optional[Any] = None,
-        max_retries: Optional[int] = None,
-        status_retries: Optional[int] = None,
-        aws_conn_id: Optional[str] = None,
-        region_name: Optional[str] = None,
-        tags: Optional[dict] = None,
+        array_properties: dict | None = None,
+        parameters: dict | None = None,
+        job_id: str | None = None,
+        waiters: Any | None = None,
+        max_retries: int | None = None,
+        status_retries: int | None = None,
+        aws_conn_id: str | None = None,
+        region_name: str | None = None,
+        tags: dict | None = None,
+        wait_for_completion: bool = True,
         **kwargs,
     ):
 
@@ -139,6 +151,7 @@ class BatchOperator(BaseOperator):
         self.parameters = parameters or {}
         self.waiters = waiters
         self.tags = tags or {}
+        self.wait_for_completion = wait_for_completion
         self.hook = BatchClientHook(
             max_retries=max_retries,
             status_retries=status_retries,
@@ -146,20 +159,24 @@ class BatchOperator(BaseOperator):
             region_name=region_name,
         )
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         """
         Submit and monitor an AWS Batch job
 
         :raises: AirflowException
         """
         self.submit_job(context)
-        self.monitor_job(context)
+
+        if self.wait_for_completion:
+            self.monitor_job(context)
+
+        return self.job_id
 
     def on_kill(self):
         response = self.hook.client.terminate_job(jobId=self.job_id, reason="Task killed by the user")
         self.log.info("AWS Batch job (%s) terminated: %s", self.job_id, response)
 
-    def submit_job(self, context: 'Context'):
+    def submit_job(self, context: Context):
         """
         Submit an AWS Batch job
 
@@ -200,7 +217,7 @@ class BatchOperator(BaseOperator):
             job_id=self.job_id,
         )
 
-    def monitor_job(self, context: 'Context'):
+    def monitor_job(self, context: Context):
         """
         Monitor an AWS Batch job
         monitor_job can raise an exception or an AirflowTaskTimeout can be raised if execution_timeout
@@ -260,17 +277,102 @@ class BatchOperator(BaseOperator):
         self.log.info("AWS Batch job (%s) succeeded", self.job_id)
 
 
-class AwsBatchOperator(BatchOperator):
+class BatchCreateComputeEnvironmentOperator(BaseOperator):
     """
-    This operator is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.operators.batch.BatchOperator`.
+    Create an AWS Batch compute environment
+
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:BatchCreateComputeEnvironmentOperator`
+
+    :param compute_environment_name: the name of the AWS batch compute environment (templated)
+
+    :param environment_type: the type of the compute-environment
+
+    :param state: the state of the compute-environment
+
+    :param compute_resources: details about the resources managed by the compute-environment (templated).
+        See more details here
+        https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/batch.html#Batch.Client.create_compute_environment
+
+    :param unmanaged_v_cpus: the maximum number of vCPU for an unmanaged compute environment.
+        This parameter is only supported when the ``type`` parameter is set to ``UNMANAGED``.
+
+    :param service_role: the IAM role that allows Batch to make calls to other AWS services on your behalf
+        (templated)
+
+    :param tags: the tags that you apply to the compute-environment to help you categorize and organize your
+        resources
+
+    :param max_retries: exponential back-off retries, 4200 = 48 hours;
+        polling is only used when waiters is None
+
+    :param status_retries: number of HTTP retries to get job status, 10;
+        polling is only used when waiters is None
+
+    :param aws_conn_id: connection id of AWS credentials / region name. If None,
+        credential boto3 strategy will be used.
+
+    :param region_name: region name to use in AWS Hook.
+        Override the region_name in connection (if provided)
     """
 
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This operator is deprecated. "
-            "Please use :class:`airflow.providers.amazon.aws.operators.batch.BatchOperator`.",
-            DeprecationWarning,
-            stacklevel=2,
+    template_fields: Sequence[str] = (
+        "compute_environment_name",
+        "compute_resources",
+        "service_role",
+    )
+    template_fields_renderers = {"compute_resources": "json"}
+
+    def __init__(
+        self,
+        compute_environment_name: str,
+        environment_type: str,
+        state: str,
+        compute_resources: dict,
+        unmanaged_v_cpus: int | None = None,
+        service_role: str | None = None,
+        tags: dict | None = None,
+        max_retries: int | None = None,
+        status_retries: int | None = None,
+        aws_conn_id: str | None = None,
+        region_name: str | None = None,
+        **kwargs,
+    ):
+        super().__init__(**kwargs)
+        self.compute_environment_name = compute_environment_name
+        self.environment_type = environment_type
+        self.state = state
+        self.unmanaged_v_cpus = unmanaged_v_cpus
+        self.compute_resources = compute_resources
+        self.service_role = service_role
+        self.tags = tags or {}
+        self.max_retries = max_retries
+        self.status_retries = status_retries
+        self.aws_conn_id = aws_conn_id
+        self.region_name = region_name
+
+    @cached_property
+    def hook(self):
+        """Create and return a BatchClientHook"""
+        return BatchClientHook(
+            max_retries=self.max_retries,
+            status_retries=self.status_retries,
+            aws_conn_id=self.aws_conn_id,
+            region_name=self.region_name,
         )
-        super().__init__(*args, **kwargs)
+
+    def execute(self, context: Context):
+        """Create an AWS batch compute environment"""
+        kwargs: dict[str, Any] = {
+            'computeEnvironmentName': self.compute_environment_name,
+            'type': self.environment_type,
+            'state': self.state,
+            'unmanagedvCpus': self.unmanaged_v_cpus,
+            'computeResources': self.compute_resources,
+            'serviceRole': self.service_role,
+            'tags': self.tags,
+        }
+        self.hook.client.create_compute_environment(**trim_none_values(kwargs))
+
+        self.log.info('AWS Batch compute environment created successfully')
