@@ -16,7 +16,9 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains CloudFormation create/delete stack operators."""
-from typing import TYPE_CHECKING, Optional, Sequence
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.cloud_formation import CloudFormationHook
@@ -29,15 +31,17 @@ class CloudFormationCreateStackOperator(BaseOperator):
     """
     An operator that creates a CloudFormation stack.
 
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:CloudFormationCreateStackOperator`
+
+
     :param stack_name: stack name (templated)
     :param cloudformation_parameters: parameters to be passed to CloudFormation.
-
-        .. seealso::
-            https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudformation.html#CloudFormation.Client.create_stack
     :param aws_conn_id: aws connection to uses
     """
 
-    template_fields: Sequence[str] = ('stack_name',)
+    template_fields: Sequence[str] = ('stack_name', 'cloudformation_parameters')
     template_ext: Sequence[str] = ()
     ui_color = '#6b9659'
 
@@ -49,7 +53,7 @@ class CloudFormationCreateStackOperator(BaseOperator):
         self.cloudformation_parameters = cloudformation_parameters
         self.aws_conn_id = aws_conn_id
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         self.log.info('CloudFormation parameters: %s', self.cloudformation_parameters)
 
         cloudformation_hook = CloudFormationHook(aws_conn_id=self.aws_conn_id)
@@ -63,8 +67,10 @@ class CloudFormationDeleteStackOperator(BaseOperator):
     :param stack_name: stack name (templated)
     :param cloudformation_parameters: parameters to be passed to CloudFormation.
 
-        .. seealso::
-            https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudformation.html#CloudFormation.Client.delete_stack
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:CloudFormationDeleteStackOperator`
+
     :param aws_conn_id: aws connection to uses
     """
 
@@ -77,7 +83,7 @@ class CloudFormationDeleteStackOperator(BaseOperator):
         self,
         *,
         stack_name: str,
-        cloudformation_parameters: Optional[dict] = None,
+        cloudformation_parameters: dict | None = None,
         aws_conn_id: str = 'aws_default',
         **kwargs,
     ):
@@ -86,7 +92,7 @@ class CloudFormationDeleteStackOperator(BaseOperator):
         self.stack_name = stack_name
         self.aws_conn_id = aws_conn_id
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         self.log.info('CloudFormation Parameters: %s', self.cloudformation_parameters)
 
         cloudformation_hook = CloudFormationHook(aws_conn_id=self.aws_conn_id)
