@@ -14,11 +14,13 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """This module contains Amazon EKS operators."""
+from __future__ import annotations
+
 import warnings
+from ast import literal_eval
 from time import sleep
-from typing import TYPE_CHECKING, Dict, List, Optional, Sequence
+from typing import TYPE_CHECKING, Any, List, Sequence, cast
 
 from airflow import AirflowException
 from airflow.models import BaseOperator
@@ -36,7 +38,6 @@ DEFAULT_CONN_ID = 'aws_default'
 DEFAULT_FARGATE_PROFILE_NAME = 'profile'
 DEFAULT_NAMESPACE_NAME = 'default'
 DEFAULT_NODEGROUP_NAME = 'nodegroup'
-DEFAULT_POD_NAME = 'pod'
 
 ABORT_MSG = "{compute} are still active after the allocated time limit.  Aborting."
 CAN_NOT_DELETE_MSG = "A cluster can not be deleted with attached {compute}.  Deleting {count} {compute}."
@@ -70,42 +71,36 @@ class EksCreateClusterOperator(BaseOperator):
         :ref:`howto/operator:EksCreateClusterOperator`
 
     :param cluster_name: The unique name to give to your Amazon EKS Cluster. (templated)
-    :type cluster_name: str
     :param cluster_role_arn: The Amazon Resource Name (ARN) of the IAM role that provides permissions for the
          Kubernetes control plane to make calls to AWS API operations on your behalf. (templated)
-    :type cluster_role_arn: str
     :param resources_vpc_config: The VPC configuration used by the cluster control plane. (templated)
-    :type resources_vpc_config: Dict
     :param compute: The type of compute architecture to generate along with the cluster. (templated)
          Defaults to 'nodegroup' to generate an EKS Managed Nodegroup.
-    :type compute: str
+    :param create_cluster_kwargs: Optional parameters to pass to the CreateCluster API (templated)
     :param aws_conn_id: The Airflow connection used for AWS credentials. (templated)
          If this is None or empty then the default boto3 behaviour is used. If
          running Airflow in a distributed manner and aws_conn_id is None or
          empty, then the default boto3 configuration would be used (and must be
          maintained on each worker node).
-    :type aws_conn_id: str
     :param region: Which AWS region the connection should use. (templated)
          If this is None or empty then the default boto3 behaviour is used.
-    :type region: str
 
-    If compute is assigned the value of 'nodegroup', the following are required:
+    If compute is assigned the value of 'nodegroup':
 
-    :param nodegroup_name: The unique name to give your Amazon EKS managed node group. (templated)
-    :type nodegroup_name: str
-    :param nodegroup_role_arn: The Amazon Resource Name (ARN) of the IAM role to associate with the
-         Amazon EKS managed node group. (templated)
-    :type nodegroup_role_arn: str
+    :param nodegroup_name: *REQUIRED* The unique name to give your Amazon EKS managed node group. (templated)
+    :param nodegroup_role_arn: *REQUIRED* The Amazon Resource Name (ARN) of the IAM role to associate with
+         the Amazon EKS managed node group. (templated)
+    :param create_nodegroup_kwargs: Optional parameters to pass to the CreateNodegroup API (templated)
 
-    If compute is assigned the value of 'fargate', the following are required:
 
-    :param fargate_profile_name: The unique name to give your AWS Fargate profile. (templated)
-    :type fargate_profile_name: str
-    :param fargate_pod_execution_role_arn: The Amazon Resource Name (ARN) of the pod execution role to
-         use for pods that match the selectors in the AWS Fargate profile. (templated)
-    :type podExecutionRoleArn: str
-    :param selectors: The selectors to match for pods to use this AWS Fargate profile. (templated)
-    :type selectors: List
+    If compute is assigned the value of 'fargate':
+
+    :param fargate_profile_name: *REQUIRED* The unique name to give your AWS Fargate profile. (templated)
+    :param fargate_pod_execution_role_arn: *REQUIRED* The Amazon Resource Name (ARN) of the pod execution
+         role to use for pods that match the selectors in the AWS Fargate profile. (templated)
+    :param fargate_selectors: The selectors to match for pods to use this AWS Fargate profile. (templated)
+    :param create_fargate_profile_kwargs: Optional parameters to pass to the CreateFargateProfile API
+         (templated)
 
     """
 
@@ -113,12 +108,15 @@ class EksCreateClusterOperator(BaseOperator):
         "cluster_name",
         "cluster_role_arn",
         "resources_vpc_config",
+        "create_cluster_kwargs",
         "compute",
         "nodegroup_name",
         "nodegroup_role_arn",
+        "create_nodegroup_kwargs",
         "fargate_profile_name",
         "fargate_pod_execution_role_arn",
         "fargate_selectors",
+        "create_fargate_profile_kwargs",
         "aws_conn_id",
         "region",
     )
@@ -127,45 +125,51 @@ class EksCreateClusterOperator(BaseOperator):
         self,
         cluster_name: str,
         cluster_role_arn: str,
-        resources_vpc_config: Dict,
-        compute: Optional[str] = DEFAULT_COMPUTE_TYPE,
-        nodegroup_name: Optional[str] = DEFAULT_NODEGROUP_NAME,
-        nodegroup_role_arn: Optional[str] = None,
-        fargate_profile_name: Optional[str] = DEFAULT_FARGATE_PROFILE_NAME,
-        fargate_pod_execution_role_arn: Optional[str] = None,
-        fargate_selectors: Optional[List] = None,
+        resources_vpc_config: dict[str, Any],
+        compute: str | None = DEFAULT_COMPUTE_TYPE,
+        create_cluster_kwargs: dict | None = None,
+        nodegroup_name: str = DEFAULT_NODEGROUP_NAME,
+        nodegroup_role_arn: str | None = None,
+        create_nodegroup_kwargs: dict | None = None,
+        fargate_profile_name: str = DEFAULT_FARGATE_PROFILE_NAME,
+        fargate_pod_execution_role_arn: str | None = None,
+        fargate_selectors: list | None = None,
+        create_fargate_profile_kwargs: dict | None = None,
         aws_conn_id: str = DEFAULT_CONN_ID,
-        region: Optional[str] = None,
+        region: str | None = None,
         **kwargs,
     ) -> None:
-        if compute:
-            if compute not in SUPPORTED_COMPUTE_VALUES:
+        self.compute = compute
+        self.cluster_name = cluster_name
+        self.cluster_role_arn = cluster_role_arn
+        self.resources_vpc_config = resources_vpc_config
+        self.create_cluster_kwargs = create_cluster_kwargs or {}
+        self.nodegroup_name = nodegroup_name
+        self.nodegroup_role_arn = nodegroup_role_arn
+        self.create_nodegroup_kwargs = create_nodegroup_kwargs or {}
+        self.fargate_profile_name = fargate_profile_name
+        self.fargate_pod_execution_role_arn = fargate_pod_execution_role_arn
+        self.fargate_selectors = fargate_selectors or [{"namespace": DEFAULT_NAMESPACE_NAME}]
+        self.create_fargate_profile_kwargs = create_fargate_profile_kwargs or {}
+        self.aws_conn_id = aws_conn_id
+        self.region = region
+        super().__init__(**kwargs)
+
+    def execute(self, context: Context):
+        if self.compute:
+            if self.compute not in SUPPORTED_COMPUTE_VALUES:
                 raise ValueError("Provided compute type is not supported.")
-            elif (compute == 'nodegroup') and not nodegroup_role_arn:
+            elif (self.compute == 'nodegroup') and not self.nodegroup_role_arn:
                 raise ValueError(
                     MISSING_ARN_MSG.format(compute=NODEGROUP_FULL_NAME, requirement='nodegroup_role_arn')
                 )
-            elif (compute == 'fargate') and not fargate_pod_execution_role_arn:
+            elif (self.compute == 'fargate') and not self.fargate_pod_execution_role_arn:
                 raise ValueError(
                     MISSING_ARN_MSG.format(
                         compute=FARGATE_FULL_NAME, requirement='fargate_pod_execution_role_arn'
                     )
                 )
 
-        self.compute = compute
-        self.cluster_name = cluster_name
-        self.cluster_role_arn = cluster_role_arn
-        self.resources_vpc_config = resources_vpc_config
-        self.nodegroup_name = nodegroup_name
-        self.nodegroup_role_arn = nodegroup_role_arn
-        self.fargate_profile_name = fargate_profile_name
-        self.fargate_pod_execution_role_arn = fargate_pod_execution_role_arn
-        self.fargate_selectors = fargate_selectors or [{"namespace": DEFAULT_NAMESPACE_NAME}]
-        self.aws_conn_id = aws_conn_id
-        self.region = region
-        super().__init__(**kwargs)
-
-    def execute(self, context: 'Context'):
         eks_hook = EksHook(
             aws_conn_id=self.aws_conn_id,
             region_name=self.region,
@@ -175,6 +179,7 @@ class EksCreateClusterOperator(BaseOperator):
             name=self.cluster_name,
             roleArn=self.cluster_role_arn,
             resourcesVpcConfig=self.resources_vpc_config,
+            **self.create_cluster_kwargs,
         )
 
         if not self.compute:
@@ -204,8 +209,9 @@ class EksCreateClusterOperator(BaseOperator):
             eks_hook.create_nodegroup(
                 clusterName=self.cluster_name,
                 nodegroupName=self.nodegroup_name,
-                subnets=self.resources_vpc_config.get('subnetIds'),
+                subnets=cast(List[str], self.resources_vpc_config.get('subnetIds')),
                 nodeRole=self.nodegroup_role_arn,
+                **self.create_nodegroup_kwargs,
             )
         elif self.compute == 'fargate':
             eks_hook.create_fargate_profile(
@@ -213,6 +219,7 @@ class EksCreateClusterOperator(BaseOperator):
                 fargateProfileName=self.fargate_profile_name,
                 podExecutionRoleArn=self.fargate_pod_execution_role_arn,
                 selectors=self.fargate_selectors,
+                **self.create_fargate_profile_kwargs,
             )
 
 
@@ -225,24 +232,19 @@ class EksCreateNodegroupOperator(BaseOperator):
         :ref:`howto/operator:EksCreateNodegroupOperator`
 
     :param cluster_name: The name of the Amazon EKS Cluster to create the managed nodegroup in. (templated)
-    :type cluster_name: str
     :param nodegroup_name: The unique name to give your managed nodegroup. (templated)
-    :type nodegroup_name: str
     :param nodegroup_subnets:
          The subnets to use for the Auto Scaling group that is created for the managed nodegroup. (templated)
-    :type nodegroup_subnets: List[str]
     :param nodegroup_role_arn:
          The Amazon Resource Name (ARN) of the IAM role to associate with the managed nodegroup. (templated)
-    :type nodegroup_role_arn: str
+    :param create_nodegroup_kwargs: Optional parameters to pass to the Create Nodegroup API (templated)
     :param aws_conn_id: The Airflow connection used for AWS credentials. (templated)
          If this is None or empty then the default boto3 behaviour is used. If
          running Airflow in a distributed manner and aws_conn_id is None or
          empty, then the default boto3 configuration would be used (and must be
          maintained on each worker node).
-    :type aws_conn_id: str
-        :param region: Which AWS region the connection should use. (templated)
+    :param region: Which AWS region the connection should use. (templated)
         If this is None or empty then the default boto3 behaviour is used.
-    :type region: str
 
     """
 
@@ -251,6 +253,7 @@ class EksCreateNodegroupOperator(BaseOperator):
         "nodegroup_subnets",
         "nodegroup_role_arn",
         "nodegroup_name",
+        "create_nodegroup_kwargs",
         "aws_conn_id",
         "region",
     )
@@ -258,32 +261,47 @@ class EksCreateNodegroupOperator(BaseOperator):
     def __init__(
         self,
         cluster_name: str,
-        nodegroup_subnets: List[str],
+        nodegroup_subnets: list[str] | str,
         nodegroup_role_arn: str,
-        nodegroup_name: Optional[str] = DEFAULT_NODEGROUP_NAME,
+        nodegroup_name: str = DEFAULT_NODEGROUP_NAME,
+        create_nodegroup_kwargs: dict | None = None,
         aws_conn_id: str = DEFAULT_CONN_ID,
-        region: Optional[str] = None,
+        region: str | None = None,
         **kwargs,
     ) -> None:
         self.cluster_name = cluster_name
-        self.nodegroup_subnets = nodegroup_subnets
         self.nodegroup_role_arn = nodegroup_role_arn
         self.nodegroup_name = nodegroup_name
+        self.create_nodegroup_kwargs = create_nodegroup_kwargs or {}
         self.aws_conn_id = aws_conn_id
         self.region = region
+        self.nodegroup_subnets = nodegroup_subnets
         super().__init__(**kwargs)
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
+        if isinstance(self.nodegroup_subnets, str):
+            nodegroup_subnets_list: list[str] = []
+            if self.nodegroup_subnets != "":
+                try:
+                    nodegroup_subnets_list = cast(List, literal_eval(self.nodegroup_subnets))
+                except ValueError:
+                    self.log.warning(
+                        "The nodegroup_subnets should be List or string representing "
+                        "Python list and is %s. Defaulting to []",
+                        self.nodegroup_subnets,
+                    )
+            self.nodegroup_subnets = nodegroup_subnets_list
+
         eks_hook = EksHook(
             aws_conn_id=self.aws_conn_id,
             region_name=self.region,
         )
-
         eks_hook.create_nodegroup(
             clusterName=self.cluster_name,
             nodegroupName=self.nodegroup_name,
             subnets=self.nodegroup_subnets,
             nodeRole=self.nodegroup_role_arn,
+            **self.create_nodegroup_kwargs,
         )
 
 
@@ -296,24 +314,20 @@ class EksCreateFargateProfileOperator(BaseOperator):
         :ref:`howto/operator:EksCreateFargateProfileOperator`
 
     :param cluster_name: The name of the Amazon EKS cluster to apply the AWS Fargate profile to. (templated)
-    :type cluster_name: str
     :param pod_execution_role_arn: The Amazon Resource Name (ARN) of the pod execution role to
          use for pods that match the selectors in the AWS Fargate profile. (templated)
-    :type pod_execution_role_arn: str
     :param selectors: The selectors to match for pods to use this AWS Fargate profile. (templated)
-    :type selectors: List
     :param fargate_profile_name: The unique name to give your AWS Fargate profile. (templated)
-    :type fargate_profile_name: str
+    :param create_fargate_profile_kwargs: Optional parameters to pass to the CreateFargate Profile API
+     (templated)
 
     :param aws_conn_id: The Airflow connection used for AWS credentials. (templated)
          If this is None or empty then the default boto3 behaviour is used. If
          running Airflow in a distributed manner and aws_conn_id is None or
          empty, then the default boto3 configuration would be used (and must be
          maintained on each worker node).
-    :type aws_conn_id: str
     :param region: Which AWS region the connection should use. (templated)
         If this is None or empty then the default boto3 behaviour is used.
-    :type region: str
     """
 
     template_fields: Sequence[str] = (
@@ -321,6 +335,7 @@ class EksCreateFargateProfileOperator(BaseOperator):
         "pod_execution_role_arn",
         "selectors",
         "fargate_profile_name",
+        "create_fargate_profile_kwargs",
         "aws_conn_id",
         "region",
     )
@@ -329,21 +344,23 @@ class EksCreateFargateProfileOperator(BaseOperator):
         self,
         cluster_name: str,
         pod_execution_role_arn: str,
-        selectors: List,
-        fargate_profile_name: Optional[str] = DEFAULT_FARGATE_PROFILE_NAME,
+        selectors: list,
+        fargate_profile_name: str | None = DEFAULT_FARGATE_PROFILE_NAME,
+        create_fargate_profile_kwargs: dict | None = None,
         aws_conn_id: str = DEFAULT_CONN_ID,
-        region: Optional[str] = None,
+        region: str | None = None,
         **kwargs,
     ) -> None:
         self.cluster_name = cluster_name
         self.pod_execution_role_arn = pod_execution_role_arn
         self.selectors = selectors
         self.fargate_profile_name = fargate_profile_name
+        self.create_fargate_profile_kwargs = create_fargate_profile_kwargs or {}
         self.aws_conn_id = aws_conn_id
         self.region = region
         super().__init__(**kwargs)
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         eks_hook = EksHook(
             aws_conn_id=self.aws_conn_id,
             region_name=self.region,
@@ -354,6 +371,7 @@ class EksCreateFargateProfileOperator(BaseOperator):
             fargateProfileName=self.fargate_profile_name,
             podExecutionRoleArn=self.pod_execution_role_arn,
             selectors=self.selectors,
+            **self.create_fargate_profile_kwargs,
         )
 
 
@@ -366,19 +384,15 @@ class EksDeleteClusterOperator(BaseOperator):
         :ref:`howto/operator:EksDeleteClusterOperator`
 
     :param cluster_name: The name of the Amazon EKS Cluster to delete. (templated)
-    :type cluster_name: str
     :param force_delete_compute: If True, will delete any attached resources. (templated)
          Defaults to False.
-    :type force_delete_compute: bool
     :param aws_conn_id: The Airflow connection used for AWS credentials. (templated)
          If this is None or empty then the default boto3 behaviour is used. If
          running Airflow in a distributed manner and aws_conn_id is None or
          empty, then the default boto3 configuration would be used (and must be
          maintained on each worker node).
-    :type aws_conn_id: str
     :param region: Which AWS region the connection should use. (templated)
         If this is None or empty then the default boto3 behaviour is used.
-    :type region: str
 
     """
 
@@ -394,7 +408,7 @@ class EksDeleteClusterOperator(BaseOperator):
         cluster_name: str,
         force_delete_compute: bool = False,
         aws_conn_id: str = DEFAULT_CONN_ID,
-        region: Optional[str] = None,
+        region: str | None = None,
         **kwargs,
     ) -> None:
         self.cluster_name = cluster_name
@@ -403,7 +417,7 @@ class EksDeleteClusterOperator(BaseOperator):
         self.region = region
         super().__init__(**kwargs)
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         eks_hook = EksHook(
             aws_conn_id=self.aws_conn_id,
             region_name=self.region,
@@ -491,18 +505,14 @@ class EksDeleteNodegroupOperator(BaseOperator):
         :ref:`howto/operator:EksDeleteNodegroupOperator`
 
     :param cluster_name: The name of the Amazon EKS Cluster associated with your nodegroup. (templated)
-    :type cluster_name: str
     :param nodegroup_name: The name of the nodegroup to delete. (templated)
-    :type nodegroup_name: str
     :param aws_conn_id: The Airflow connection used for AWS credentials. (templated)
          If this is None or empty then the default boto3 behaviour is used.  If
          running Airflow in a distributed manner and aws_conn_id is None or
          empty, then the default boto3 configuration would be used (and must be
          maintained on each worker node).
-    :type aws_conn_id: str
     :param region: Which AWS region the connection should use. (templated)
         If this is None or empty then the default boto3 behaviour is used.
-    :type region: str
 
     """
 
@@ -518,7 +528,7 @@ class EksDeleteNodegroupOperator(BaseOperator):
         cluster_name: str,
         nodegroup_name: str,
         aws_conn_id: str = DEFAULT_CONN_ID,
-        region: Optional[str] = None,
+        region: str | None = None,
         **kwargs,
     ) -> None:
         self.cluster_name = cluster_name
@@ -527,7 +537,7 @@ class EksDeleteNodegroupOperator(BaseOperator):
         self.region = region
         super().__init__(**kwargs)
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         eks_hook = EksHook(
             aws_conn_id=self.aws_conn_id,
             region_name=self.region,
@@ -545,18 +555,14 @@ class EksDeleteFargateProfileOperator(BaseOperator):
         :ref:`howto/operator:EksDeleteFargateProfileOperator`
 
     :param cluster_name: The name of the Amazon EKS cluster associated with your Fargate profile. (templated)
-    :type cluster_name: str
     :param fargate_profile_name: The name of the AWS Fargate profile to delete. (templated)
-    :type fargate_profile_name: str
     :param aws_conn_id: The Airflow connection used for AWS credentials. (templated)
          If this is None or empty then the default boto3 behaviour is used.  If
          running Airflow in a distributed manner and aws_conn_id is None or
          empty, then the default boto3 configuration would be used (and must be
          maintained on each worker node).
-    :type aws_conn_id: str
     :param region: Which AWS region the connection should use. (templated)
         If this is None or empty then the default boto3 behaviour is used.
-    :type region: str
     """
 
     template_fields: Sequence[str] = (
@@ -571,7 +577,7 @@ class EksDeleteFargateProfileOperator(BaseOperator):
         cluster_name: str,
         fargate_profile_name: str,
         aws_conn_id: str = DEFAULT_CONN_ID,
-        region: Optional[str] = None,
+        region: str | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -580,7 +586,7 @@ class EksDeleteFargateProfileOperator(BaseOperator):
         self.aws_conn_id = aws_conn_id
         self.region = region
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         eks_hook = EksHook(
             aws_conn_id=self.aws_conn_id,
             region_name=self.region,
@@ -600,32 +606,24 @@ class EksPodOperator(KubernetesPodOperator):
         :ref:`howto/operator:EksPodOperator`
 
     :param cluster_name: The name of the Amazon EKS Cluster to execute the task on. (templated)
-    :type cluster_name: str
     :param cluster_role_arn: The Amazon Resource Name (ARN) of the IAM role that provides permissions
          for the Kubernetes control plane to make calls to AWS API operations on your behalf. (templated)
-    :type cluster_role_arn: str
     :param in_cluster: If True, look for config inside the cluster; if False look for a local file path.
-    :type in_cluster: bool
     :param namespace: The namespace in which to execute the pod. (templated)
-    :type namespace: str
     :param pod_name: The unique name to give the pod. (templated)
-    :type pod_name: str
     :param aws_profile: The named profile containing the credentials for the AWS CLI tool to use.
     :param aws_profile: str
     :param region: Which AWS region the connection should use. (templated)
          If this is None or empty then the default boto3 behaviour is used.
-    :type region: str
     :param aws_conn_id: The Airflow connection used for AWS credentials. (templated)
          If this is None or empty then the default boto3 behaviour is used. If
          running Airflow in a distributed manner and aws_conn_id is None or
          empty, then the default boto3 configuration would be used (and must be
          maintained on each worker node).
-    :type aws_conn_id: str
     :param is_delete_operator_pod: What to do when the pod reaches its final
         state, or the execution is interrupted. If True, delete the
         pod; if False, leave the pod.  Current default is False, but this will be
         changed in the next major release of this provider.
-    :type is_delete_operator_pod: bool
 
     """
 
@@ -648,23 +646,14 @@ class EksPodOperator(KubernetesPodOperator):
         # file is stored locally in the worker and not in the cluster.
         in_cluster: bool = False,
         namespace: str = DEFAULT_NAMESPACE_NAME,
-        pod_context: Optional[str] = None,
-        pod_name: Optional[str] = None,
-        pod_username: Optional[str] = None,
+        pod_context: str | None = None,
+        pod_name: str | None = None,
+        pod_username: str | None = None,
         aws_conn_id: str = DEFAULT_CONN_ID,
-        region: Optional[str] = None,
-        is_delete_operator_pod: Optional[bool] = None,
+        region: str | None = None,
+        is_delete_operator_pod: bool | None = None,
         **kwargs,
     ) -> None:
-        if pod_name is None:
-            warnings.warn(
-                "Default value of pod name is deprecated. "
-                "We recommend that you pass pod name explicitly. ",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-            pod_name = DEFAULT_POD_NAME
-
         if is_delete_operator_pod is None:
             warnings.warn(
                 f"You have not set parameter `is_delete_operator_pod` in class {self.__class__.__name__}. "
@@ -689,26 +678,12 @@ class EksPodOperator(KubernetesPodOperator):
             is_delete_operator_pod=is_delete_operator_pod,
             **kwargs,
         )
-        if pod_username:
-            warnings.warn(
-                "This pod_username parameter is deprecated, because changing the value does not make any "
-                "visible changes to the user.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-        if pod_context:
-            warnings.warn(
-                "This pod_context parameter is deprecated, because changing the value does not make any "
-                "visible changes to the user.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
         # There is no need to manage the kube_config file, as it will be generated automatically.
         # All Kubernetes parameters (except config_file) are also valid for the EksPodOperator.
         if self.config_file:
             raise AirflowException("The config_file is not an allowed parameter for the EksPodOperator.")
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         eks_hook = EksHook(
             aws_conn_id=self.aws_conn_id,
             region_name=self.region,
@@ -717,115 +692,3 @@ class EksPodOperator(KubernetesPodOperator):
             eks_cluster_name=self.cluster_name, pod_namespace=self.namespace
         ) as self.config_file:
             return super().execute(context)
-
-
-class EKSCreateClusterOperator(EksCreateClusterOperator):
-    """
-    This operator is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.operators.eks.EksCreateClusterOperator`.
-    """
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This operator is deprecated. "
-            "Please use `airflow.providers.amazon.aws.operators.eks.EksCreateClusterOperator`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        super().__init__(*args, **kwargs)
-
-
-class EKSCreateNodegroupOperator(EksCreateNodegroupOperator):
-    """
-    This operator is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.operators.eks.EksCreateNodegroupOperator`.
-    """
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This operator is deprecated. "
-            "Please use `airflow.providers.amazon.aws.operators.eks.EksCreateNodegroupOperator`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        super().__init__(*args, **kwargs)
-
-
-class EKSCreateFargateProfileOperator(EksCreateFargateProfileOperator):
-    """
-    This operator is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.operators.eks.EksCreateFargateProfileOperator`.
-    """
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This operator is deprecated. "
-            "Please use `airflow.providers.amazon.aws.operators.eks.EksCreateFargateProfileOperator`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        super().__init__(*args, **kwargs)
-
-
-class EKSDeleteClusterOperator(EksDeleteClusterOperator):
-    """
-    This operator is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.operators.eks.EksDeleteClusterOperator`.
-    """
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This operator is deprecated. "
-            "Please use `airflow.providers.amazon.aws.operators.eks.EksDeleteClusterOperator`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        super().__init__(*args, **kwargs)
-
-
-class EKSDeleteNodegroupOperator(EksDeleteNodegroupOperator):
-    """
-    This operator is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.operators.eks.EksDeleteNodegroupOperator`.
-    """
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This operator is deprecated. "
-            "Please use `airflow.providers.amazon.aws.operators.eks.EksDeleteNodegroupOperator`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        super().__init__(*args, **kwargs)
-
-
-class EKSDeleteFargateProfileOperator(EksDeleteFargateProfileOperator):
-    """
-    This operator is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.operators.eks.EksDeleteFargateProfileOperator`.
-    """
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This operator is deprecated. "
-            "Please use `airflow.providers.amazon.aws.operators.eks.EksDeleteFargateProfileOperator`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        super().__init__(*args, **kwargs)
-
-
-class EKSPodOperator(EksPodOperator):
-    """
-    This operator is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.operators.eks.EksPodOperator`.
-    """
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This operator is deprecated. "
-            "Please use `airflow.providers.amazon.aws.operators.eks.EksPodOperator`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        super().__init__(*args, **kwargs)
