@@ -15,6 +15,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
+
 from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
@@ -33,9 +35,7 @@ class GlacierCreateJobOperator(BaseOperator):
         :ref:`howto/operator:GlacierCreateJobOperator`
 
     :param aws_conn_id: The reference to the AWS connection details
-    :type aws_conn_id: str
     :param vault_name: the Glacier vault on which job is executed
-    :type vault_name: str
     """
 
     template_fields: Sequence[str] = ("vault_name",)
@@ -51,7 +51,6 @@ class GlacierCreateJobOperator(BaseOperator):
         self.aws_conn_id = aws_conn_id
         self.vault_name = vault_name
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = GlacierHook(aws_conn_id=self.aws_conn_id)
-        response = hook.retrieve_inventory(vault_name=self.vault_name)
-        return response
+        return hook.retrieve_inventory(vault_name=self.vault_name)
