@@ -15,10 +15,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
 import os.path
-import warnings
-from typing import TYPE_CHECKING, Optional, Sequence
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.glue import GlueJobHook
@@ -51,9 +51,16 @@ class GlueJobOperator(BaseOperator):
     :param create_job_kwargs: Extra arguments for Glue Job Creation
     :param run_job_kwargs: Extra arguments for Glue Job Run
     :param wait_for_completion: Whether or not wait for job run completion. (default: True)
+    :param verbose: If True, Glue Job Run logs show in the Airflow Task Logs.  (default: False)
     """
 
-    template_fields: Sequence[str] = ('script_args',)
+    template_fields: Sequence[str] = (
+        'job_name',
+        'script_location',
+        'script_args',
+        's3_bucket',
+        'iam_role_name',
+    )
     template_ext: Sequence[str] = ()
     template_fields_renderers = {
         "script_args": "json",
@@ -66,18 +73,19 @@ class GlueJobOperator(BaseOperator):
         *,
         job_name: str = 'aws_glue_default_job',
         job_desc: str = 'AWS Glue Job with Airflow',
-        script_location: Optional[str] = None,
-        concurrent_run_limit: Optional[int] = None,
-        script_args: Optional[dict] = None,
+        script_location: str | None = None,
+        concurrent_run_limit: int | None = None,
+        script_args: dict | None = None,
         retry_limit: int = 0,
-        num_of_dpus: Optional[int] = None,
+        num_of_dpus: int | None = None,
         aws_conn_id: str = 'aws_default',
-        region_name: Optional[str] = None,
-        s3_bucket: Optional[str] = None,
-        iam_role_name: Optional[str] = None,
-        create_job_kwargs: Optional[dict] = None,
-        run_job_kwargs: Optional[dict] = None,
+        region_name: str | None = None,
+        s3_bucket: str | None = None,
+        iam_role_name: str | None = None,
+        create_job_kwargs: dict | None = None,
+        run_job_kwargs: dict | None = None,
         wait_for_completion: bool = True,
+        verbose: bool = False,
         **kwargs,
     ):
         super().__init__(**kwargs)
@@ -97,8 +105,9 @@ class GlueJobOperator(BaseOperator):
         self.create_job_kwargs = create_job_kwargs
         self.run_job_kwargs = run_job_kwargs or {}
         self.wait_for_completion = wait_for_completion
+        self.verbose = verbose
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         """
         Executes AWS Glue Job from Airflow
 
@@ -135,7 +144,7 @@ class GlueJobOperator(BaseOperator):
         )
         glue_job_run = glue_job.initialize_job(self.script_args, self.run_job_kwargs)
         if self.wait_for_completion:
-            glue_job_run = glue_job.job_completion(self.job_name, glue_job_run['JobRunId'])
+            glue_job_run = glue_job.job_completion(self.job_name, glue_job_run['JobRunId'], self.verbose)
             self.log.info(
                 "AWS Glue Job: %s status: %s. Run Id: %s",
                 self.job_name,
@@ -145,19 +154,3 @@ class GlueJobOperator(BaseOperator):
         else:
             self.log.info("AWS Glue Job: %s. Run Id: %s", self.job_name, glue_job_run['JobRunId'])
         return glue_job_run['JobRunId']
-
-
-class AwsGlueJobOperator(GlueJobOperator):
-    """
-    This operator is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.operators.glue.GlueJobOperator`.
-    """
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This operator is deprecated. "
-            "Please use :class:`airflow.providers.amazon.aws.operators.glue.GlueJobOperator`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        super().__init__(*args, **kwargs)
