@@ -14,9 +14,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
 import json
-from typing import TYPE_CHECKING, Any, List, Optional, Sequence
+from typing import TYPE_CHECKING, Any, Sequence
 
 from botocore.exceptions import ClientError
 
@@ -25,12 +26,17 @@ from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 from airflow.providers.amazon.aws.hooks.sagemaker import SageMakerHook
+from airflow.utils.json import AirflowJsonEncoder
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
-DEFAULT_CONN_ID = 'aws_default'
-CHECK_INTERVAL_SECOND = 30
+DEFAULT_CONN_ID: str = 'aws_default'
+CHECK_INTERVAL_SECOND: int = 30
+
+
+def serialize(result: dict) -> str:
+    return json.loads(json.dumps(result, cls=AirflowJsonEncoder))
 
 
 class SageMakerBaseOperator(BaseOperator):
@@ -41,15 +47,15 @@ class SageMakerBaseOperator(BaseOperator):
 
     template_fields: Sequence[str] = ('config',)
     template_ext: Sequence[str] = ()
-    template_fields_renderers = {'config': 'json'}
-    ui_color = '#ededed'
-    integer_fields: List[List[Any]] = []
+    template_fields_renderers: dict = {'config': 'json'}
+    ui_color: str = '#ededed'
+    integer_fields: list[list[Any]] = []
 
     def __init__(self, *, config: dict, **kwargs):
         super().__init__(**kwargs)
         self.config = config
 
-    def parse_integer(self, config, field):
+    def parse_integer(self, config: dict, field: list[str] | str) -> None:
         """Recursive method for parsing string fields holding integer values to integers."""
         if len(field) == 1:
             if isinstance(config, list):
@@ -69,19 +75,17 @@ class SageMakerBaseOperator(BaseOperator):
             self.parse_integer(config[head], tail)
         return
 
-    def parse_config_integers(self):
-        """
-        Parse the integer fields of training config to integers in case the config is rendered by Jinja and
-        all fields are str
-        """
+    def parse_config_integers(self) -> None:
+        """Parse the integer fields to ints in case the config is rendered by Jinja and all fields are str."""
         for field in self.integer_fields:
             self.parse_integer(self.config, field)
 
-    def expand_role(self):
+    def expand_role(self) -> None:
         """Placeholder for calling boto3's `expand_role`, which expands an IAM role name into an ARN."""
 
-    def preprocess_config(self):
+    def preprocess_config(self) -> None:
         """Process the config into a usable form."""
+        self._create_integer_fields()
         self.log.info('Preprocessing the config and doing required s3_operations')
         self.hook.configure_s3_resources(self.config)
         self.parse_config_integers()
@@ -91,12 +95,19 @@ class SageMakerBaseOperator(BaseOperator):
             json.dumps(self.config, sort_keys=True, indent=4, separators=(',', ': ')),
         )
 
-    def execute(self, context: 'Context'):
+    def _create_integer_fields(self) -> None:
+        """
+        Set fields which should be cast to integers.
+        Child classes should override this method if they need integer fields parsed.
+        """
+        self.integer_fields = []
+
+    def execute(self, context: Context) -> None | dict:
         raise NotImplementedError('Please implement execute() in sub class!')
 
     @cached_property
     def hook(self):
-        """Return SageMakerHook"""
+        """Return SageMakerHook."""
         return SageMakerHook(aws_conn_id=self.aws_conn_id)
 
 
@@ -135,7 +146,7 @@ class SageMakerProcessingOperator(SageMakerBaseOperator):
         wait_for_completion: bool = True,
         print_log: bool = True,
         check_interval: int = CHECK_INTERVAL_SECOND,
-        max_ingestion_time: Optional[int] = None,
+        max_ingestion_time: int | None = None,
         action_if_job_exists: str = 'increment',
         **kwargs,
     ):
@@ -151,23 +162,23 @@ class SageMakerProcessingOperator(SageMakerBaseOperator):
         self.print_log = print_log
         self.check_interval = check_interval
         self.max_ingestion_time = max_ingestion_time
-        self._create_integer_fields()
 
     def _create_integer_fields(self) -> None:
-        """Set fields which should be casted to integers."""
-        self.integer_fields = [
+        """Set fields which should be cast to integers."""
+        self.integer_fields: list[list[str] | list[list[str]]] = [
             ['ProcessingResources', 'ClusterConfig', 'InstanceCount'],
             ['ProcessingResources', 'ClusterConfig', 'VolumeSizeInGB'],
         ]
         if 'StoppingCondition' in self.config:
-            self.integer_fields += [['StoppingCondition', 'MaxRuntimeInSeconds']]
+            self.integer_fields.append(['StoppingCondition', 'MaxRuntimeInSeconds'])
 
     def expand_role(self) -> None:
+        """Expands an IAM role name into an ARN."""
         if 'RoleArn' in self.config:
             hook = AwsBaseHook(self.aws_conn_id, client_type='iam')
             self.config['RoleArn'] = hook.expand_role(self.config['RoleArn'])
 
-    def execute(self, context: 'Context') -> dict:
+    def execute(self, context: Context) -> dict:
         self.preprocess_config()
         processing_job_name = self.config['ProcessingJobName']
         if self.hook.find_processing_job_by_name(processing_job_name):
@@ -183,7 +194,7 @@ class SageMakerProcessingOperator(SageMakerBaseOperator):
         )
         if response['ResponseMetadata']['HTTPStatusCode'] != 200:
             raise AirflowException(f'Sagemaker Processing Job creation failed: {response}')
-        return {'Processing': self.hook.describe_processing_job(self.config['ProcessingJobName'])}
+        return {'Processing': serialize(self.hook.describe_processing_job(self.config['ProcessingJobName']))}
 
 
 class SageMakerEndpointConfigOperator(SageMakerBaseOperator):
@@ -204,8 +215,6 @@ class SageMakerEndpointConfigOperator(SageMakerBaseOperator):
     :return Dict: Returns The ARN of the endpoint config created in Amazon SageMaker.
     """
 
-    integer_fields = [['ProductionVariants', 'InitialInstanceCount']]
-
     def __init__(
         self,
         *,
@@ -217,14 +226,22 @@ class SageMakerEndpointConfigOperator(SageMakerBaseOperator):
         self.config = config
         self.aws_conn_id = aws_conn_id
 
-    def execute(self, context: 'Context') -> dict:
+    def _create_integer_fields(self) -> None:
+        """Set fields which should be cast to integers."""
+        self.integer_fields: list[list[str]] = [['ProductionVariants', 'InitialInstanceCount']]
+
+    def execute(self, context: Context) -> dict:
         self.preprocess_config()
         self.log.info('Creating SageMaker Endpoint Config %s.', self.config['EndpointConfigName'])
         response = self.hook.create_endpoint_config(self.config)
         if response['ResponseMetadata']['HTTPStatusCode'] != 200:
             raise AirflowException(f'Sagemaker endpoint config creation failed: {response}')
         else:
-            return {'EndpointConfig': self.hook.describe_endpoint_config(self.config['EndpointConfigName'])}
+            return {
+                'EndpointConfig': serialize(
+                    self.hook.describe_endpoint_config(self.config['EndpointConfigName'])
+                )
+            }
 
 
 class SageMakerEndpointOperator(SageMakerBaseOperator):
@@ -282,7 +299,7 @@ class SageMakerEndpointOperator(SageMakerBaseOperator):
         aws_conn_id: str = DEFAULT_CONN_ID,
         wait_for_completion: bool = True,
         check_interval: int = CHECK_INTERVAL_SECOND,
-        max_ingestion_time: Optional[int] = None,
+        max_ingestion_time: int | None = None,
         operation: str = 'create',
         **kwargs,
     ):
@@ -295,14 +312,16 @@ class SageMakerEndpointOperator(SageMakerBaseOperator):
         self.operation = operation.lower()
         if self.operation not in ['create', 'update']:
             raise ValueError('Invalid value! Argument operation has to be one of "create" and "update"')
-        self.create_integer_fields()
 
-    def create_integer_fields(self) -> None:
-        """Set fields which should be casted to integers."""
+    def _create_integer_fields(self) -> None:
+        """Set fields which should be cast to integers."""
         if 'EndpointConfig' in self.config:
-            self.integer_fields = [['EndpointConfig', 'ProductionVariants', 'InitialInstanceCount']]
+            self.integer_fields: list[list[str]] = [
+                ['EndpointConfig', 'ProductionVariants', 'InitialInstanceCount']
+            ]
 
     def expand_role(self) -> None:
+        """Expands an IAM role name into an ARN."""
         if 'Model' not in self.config:
             return
         hook = AwsBaseHook(self.aws_conn_id, client_type='iam')
@@ -310,7 +329,7 @@ class SageMakerEndpointOperator(SageMakerBaseOperator):
         if 'ExecutionRoleArn' in config:
             config['ExecutionRoleArn'] = hook.expand_role(config['ExecutionRoleArn'])
 
-    def execute(self, context: 'Context') -> dict:
+    def execute(self, context: Context) -> dict:
         self.preprocess_config()
         model_info = self.config.get('Model')
         endpoint_config_info = self.config.get('EndpointConfig')
@@ -351,8 +370,10 @@ class SageMakerEndpointOperator(SageMakerBaseOperator):
             raise AirflowException(f'Sagemaker endpoint creation failed: {response}')
         else:
             return {
-                'EndpointConfig': self.hook.describe_endpoint_config(endpoint_info['EndpointConfigName']),
-                'Endpoint': self.hook.describe_endpoint(endpoint_info['EndpointName']),
+                'EndpointConfig': serialize(
+                    self.hook.describe_endpoint_config(endpoint_info['EndpointConfigName'])
+                ),
+                'Endpoint': serialize(self.hook.describe_endpoint(endpoint_info['EndpointName'])),
             }
 
 
@@ -391,6 +412,11 @@ class SageMakerTransformOperator(SageMakerBaseOperator):
     :param max_ingestion_time: If wait is set to True, the operation fails
         if the transform job doesn't finish within max_ingestion_time seconds. If you
         set this parameter to None, the operation does not timeout.
+    :param check_if_job_exists: If set to true, then the operator will check whether a transform job
+        already exists for the name in the config.
+    :param action_if_job_exists: Behaviour if the job name already exists. Possible options are "increment"
+        (default) and "fail".
+        This is only relevant if check_if_job_exists is True.
     :return Dict: Returns The ARN of the model created in Amazon SageMaker.
     """
 
@@ -401,7 +427,9 @@ class SageMakerTransformOperator(SageMakerBaseOperator):
         aws_conn_id: str = DEFAULT_CONN_ID,
         wait_for_completion: bool = True,
         check_interval: int = CHECK_INTERVAL_SECOND,
-        max_ingestion_time: Optional[int] = None,
+        max_ingestion_time: int | None = None,
+        check_if_job_exists: bool = True,
+        action_if_job_exists: str = 'increment',
         **kwargs,
     ):
         super().__init__(config=config, **kwargs)
@@ -410,11 +438,18 @@ class SageMakerTransformOperator(SageMakerBaseOperator):
         self.wait_for_completion = wait_for_completion
         self.check_interval = check_interval
         self.max_ingestion_time = max_ingestion_time
-        self.create_integer_fields()
+        self.check_if_job_exists = check_if_job_exists
+        if action_if_job_exists in ('increment', 'fail'):
+            self.action_if_job_exists = action_if_job_exists
+        else:
+            raise AirflowException(
+                f"Argument action_if_job_exists accepts only 'increment' and 'fail'. \
+                Provided value: '{action_if_job_exists}'."
+            )
 
-    def create_integer_fields(self) -> None:
-        """Set fields which should be casted to integers."""
-        self.integer_fields: List[List[str]] = [
+    def _create_integer_fields(self) -> None:
+        """Set fields which should be cast to integers."""
+        self.integer_fields: list[list[str]] = [
             ['Transform', 'TransformResources', 'InstanceCount'],
             ['Transform', 'MaxConcurrentTransforms'],
             ['Transform', 'MaxPayloadInMB'],
@@ -424,6 +459,7 @@ class SageMakerTransformOperator(SageMakerBaseOperator):
                 field.pop(0)
 
     def expand_role(self) -> None:
+        """Expands an IAM role name into an ARN."""
         if 'Model' not in self.config:
             return
         config = self.config['Model']
@@ -431,10 +467,12 @@ class SageMakerTransformOperator(SageMakerBaseOperator):
             hook = AwsBaseHook(self.aws_conn_id, client_type='iam')
             config['ExecutionRoleArn'] = hook.expand_role(config['ExecutionRoleArn'])
 
-    def execute(self, context: 'Context') -> dict:
+    def execute(self, context: Context) -> dict:
         self.preprocess_config()
         model_config = self.config.get('Model')
         transform_config = self.config.get('Transform', self.config)
+        if self.check_if_job_exists:
+            self._check_if_transform_job_exists()
         if model_config:
             self.log.info('Creating SageMaker Model %s for transform job', model_config['ModelName'])
             self.hook.create_model(model_config)
@@ -449,10 +487,27 @@ class SageMakerTransformOperator(SageMakerBaseOperator):
             raise AirflowException(f'Sagemaker transform Job creation failed: {response}')
         else:
             return {
-                'Model': self.hook.describe_model(transform_config['ModelName']),
-                'Transform': self.hook.describe_transform_job(transform_config['TransformJobName']),
+                'Model': serialize(self.hook.describe_model(transform_config['ModelName'])),
+                'Transform': serialize(
+                    self.hook.describe_transform_job(transform_config['TransformJobName'])
+                ),
             }
 
+    def _check_if_transform_job_exists(self) -> None:
+        transform_config = self.config.get('Transform', self.config)
+        transform_job_name = transform_config['TransformJobName']
+        transform_jobs = self.hook.list_transform_jobs(name_contains=transform_job_name)
+        if transform_job_name in [tj['TransformJobName'] for tj in transform_jobs]:
+            if self.action_if_job_exists == 'increment':
+                self.log.info("Found existing transform job with name '%s'.", transform_job_name)
+                new_transform_job_name = f'{transform_job_name}-{(len(transform_jobs) + 1)}'
+                transform_config['TransformJobName'] = new_transform_job_name
+                self.log.info("Incremented transform job name to '%s'.", new_transform_job_name)
+            elif self.action_if_job_exists == 'fail':
+                raise AirflowException(
+                    f'A SageMaker transform job with name {transform_job_name} already exists.'
+                )
+
 
 class SageMakerTuningOperator(SageMakerBaseOperator):
     """
@@ -480,14 +535,6 @@ class SageMakerTuningOperator(SageMakerBaseOperator):
     :return Dict: Returns The ARN of the tuning job created in Amazon SageMaker.
     """
 
-    integer_fields = [
-        ['HyperParameterTuningJobConfig', 'ResourceLimits', 'MaxNumberOfTrainingJobs'],
-        ['HyperParameterTuningJobConfig', 'ResourceLimits', 'MaxParallelTrainingJobs'],
-        ['TrainingJobDefinition', 'ResourceConfig', 'InstanceCount'],
-        ['TrainingJobDefinition', 'ResourceConfig', 'VolumeSizeInGB'],
-        ['TrainingJobDefinition', 'StoppingCondition', 'MaxRuntimeInSeconds'],
-    ]
-
     def __init__(
         self,
         *,
@@ -495,7 +542,7 @@ class SageMakerTuningOperator(SageMakerBaseOperator):
         aws_conn_id: str = DEFAULT_CONN_ID,
         wait_for_completion: bool = True,
         check_interval: int = CHECK_INTERVAL_SECOND,
-        max_ingestion_time: Optional[int] = None,
+        max_ingestion_time: int | None = None,
         **kwargs,
     ):
         super().__init__(config=config, **kwargs)
@@ -506,13 +553,24 @@ class SageMakerTuningOperator(SageMakerBaseOperator):
         self.max_ingestion_time = max_ingestion_time
 
     def expand_role(self) -> None:
+        """Expands an IAM role name into an ARN."""
         if 'TrainingJobDefinition' in self.config:
             config = self.config['TrainingJobDefinition']
             if 'RoleArn' in config:
                 hook = AwsBaseHook(self.aws_conn_id, client_type='iam')
                 config['RoleArn'] = hook.expand_role(config['RoleArn'])
 
-    def execute(self, context: 'Context') -> dict:
+    def _create_integer_fields(self) -> None:
+        """Set fields which should be cast to integers."""
+        self.integer_fields: list[list[str]] = [
+            ['HyperParameterTuningJobConfig', 'ResourceLimits', 'MaxNumberOfTrainingJobs'],
+            ['HyperParameterTuningJobConfig', 'ResourceLimits', 'MaxParallelTrainingJobs'],
+            ['TrainingJobDefinition', 'ResourceConfig', 'InstanceCount'],
+            ['TrainingJobDefinition', 'ResourceConfig', 'VolumeSizeInGB'],
+            ['TrainingJobDefinition', 'StoppingCondition', 'MaxRuntimeInSeconds'],
+        ]
+
+    def execute(self, context: Context) -> dict:
         self.preprocess_config()
         self.log.info(
             'Creating SageMaker Hyper-Parameter Tuning Job %s', self.config['HyperParameterTuningJobName']
@@ -526,7 +584,9 @@ class SageMakerTuningOperator(SageMakerBaseOperator):
         if response['ResponseMetadata']['HTTPStatusCode'] != 200:
             raise AirflowException(f'Sagemaker Tuning Job creation failed: {response}')
         else:
-            return {'Tuning': self.hook.describe_tuning_job(self.config['HyperParameterTuningJobName'])}
+            return {
+                'Tuning': serialize(self.hook.describe_tuning_job(self.config['HyperParameterTuningJobName']))
+            }
 
 
 class SageMakerModelOperator(SageMakerBaseOperator):
@@ -547,24 +607,25 @@ class SageMakerModelOperator(SageMakerBaseOperator):
     :return Dict: Returns The ARN of the model created in Amazon SageMaker.
     """
 
-    def __init__(self, *, config, aws_conn_id: str = DEFAULT_CONN_ID, **kwargs):
+    def __init__(self, *, config: dict, aws_conn_id: str = DEFAULT_CONN_ID, **kwargs):
         super().__init__(config=config, **kwargs)
         self.config = config
         self.aws_conn_id = aws_conn_id
 
     def expand_role(self) -> None:
+        """Expands an IAM role name into an ARN."""
         if 'ExecutionRoleArn' in self.config:
             hook = AwsBaseHook(self.aws_conn_id, client_type='iam')
             self.config['ExecutionRoleArn'] = hook.expand_role(self.config['ExecutionRoleArn'])
 
-    def execute(self, context: 'Context') -> dict:
+    def execute(self, context: Context) -> dict:
         self.preprocess_config()
         self.log.info('Creating SageMaker Model %s.', self.config['ModelName'])
         response = self.hook.create_model(self.config)
         if response['ResponseMetadata']['HTTPStatusCode'] != 200:
             raise AirflowException(f'Sagemaker model creation failed: {response}')
         else:
-            return {'Model': self.hook.describe_model(self.config['ModelName'])}
+            return {'Model': serialize(self.hook.describe_model(self.config['ModelName']))}
 
 
 class SageMakerTrainingOperator(SageMakerBaseOperator):
@@ -592,16 +653,10 @@ class SageMakerTrainingOperator(SageMakerBaseOperator):
         already exists for the name in the config.
     :param action_if_job_exists: Behaviour if the job name already exists. Possible options are "increment"
         (default) and "fail".
-        This is only relevant if check_if
+        This is only relevant if check_if_job_exists is True.
     :return Dict: Returns The ARN of the training job created in Amazon SageMaker.
     """
 
-    integer_fields = [
-        ['ResourceConfig', 'InstanceCount'],
-        ['ResourceConfig', 'VolumeSizeInGB'],
-        ['StoppingCondition', 'MaxRuntimeInSeconds'],
-    ]
-
     def __init__(
         self,
         *,
@@ -610,7 +665,7 @@ class SageMakerTrainingOperator(SageMakerBaseOperator):
         wait_for_completion: bool = True,
         print_log: bool = True,
         check_interval: int = CHECK_INTERVAL_SECOND,
-        max_ingestion_time: Optional[int] = None,
+        max_ingestion_time: int | None = None,
         check_if_job_exists: bool = True,
         action_if_job_exists: str = 'increment',
         **kwargs,
@@ -631,11 +686,20 @@ class SageMakerTrainingOperator(SageMakerBaseOperator):
             )
 
     def expand_role(self) -> None:
+        """Expands an IAM role name into an ARN."""
         if 'RoleArn' in self.config:
             hook = AwsBaseHook(self.aws_conn_id, client_type='iam')
             self.config['RoleArn'] = hook.expand_role(self.config['RoleArn'])
 
-    def execute(self, context: 'Context') -> dict:
+    def _create_integer_fields(self) -> None:
+        """Set fields which should be cast to integers."""
+        self.integer_fields: list[list[str]] = [
+            ['ResourceConfig', 'InstanceCount'],
+            ['ResourceConfig', 'VolumeSizeInGB'],
+            ['StoppingCondition', 'MaxRuntimeInSeconds'],
+        ]
+
+    def execute(self, context: Context) -> dict:
         self.preprocess_config()
         if self.check_if_job_exists:
             self._check_if_job_exists()
@@ -650,7 +714,7 @@ class SageMakerTrainingOperator(SageMakerBaseOperator):
         if response['ResponseMetadata']['HTTPStatusCode'] != 200:
             raise AirflowException(f'Sagemaker Training Job creation failed: {response}')
         else:
-            return {'Training': self.hook.describe_training_job(self.config['TrainingJobName'])}
+            return {'Training': serialize(self.hook.describe_training_job(self.config['TrainingJobName']))}
 
     def _check_if_job_exists(self) -> None:
         training_job_name = self.config['TrainingJobName']
@@ -680,12 +744,12 @@ class SageMakerDeleteModelOperator(SageMakerBaseOperator):
     :param aws_conn_id: The AWS connection ID to use.
     """
 
-    def __init__(self, *, config, aws_conn_id: str = DEFAULT_CONN_ID, **kwargs):
+    def __init__(self, *, config: dict, aws_conn_id: str = DEFAULT_CONN_ID, **kwargs):
         super().__init__(config=config, **kwargs)
         self.config = config
         self.aws_conn_id = aws_conn_id
 
-    def execute(self, context: 'Context') -> Any:
+    def execute(self, context: Context) -> Any:
         sagemaker_hook = SageMakerHook(aws_conn_id=self.aws_conn_id)
         sagemaker_hook.delete_model(model_name=self.config['ModelName'])
         self.log.info("Model %s deleted successfully.", self.config['ModelName'])
