@@ -15,9 +15,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
 """Publish message to SNS queue"""
-from typing import TYPE_CHECKING, Optional, Sequence
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.sns import SnsHook
@@ -30,20 +31,19 @@ class SnsPublishOperator(BaseOperator):
     """
     Publish a message to Amazon SNS.
 
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:SnsPublishOperator`
+
     :param aws_conn_id: aws connection to use
-    :type aws_conn_id: str
     :param target_arn: either a TopicArn or an EndpointArn
-    :type target_arn: str
     :param message: the default message you want to send (templated)
-    :type message: str
     :param subject: the message subject you want to send (templated)
-    :type subject: str
     :param message_attributes: the message attributes you want to send as a flat dict (data type will be
         determined automatically)
-    :type message_attributes: dict
     """
 
-    template_fields: Sequence[str] = ('message', 'subject', 'message_attributes')
+    template_fields: Sequence[str] = ('target_arn', 'message', 'subject', 'message_attributes', 'aws_conn_id')
     template_ext: Sequence[str] = ()
     template_fields_renderers = {"message_attributes": "json"}
 
@@ -52,9 +52,9 @@ class SnsPublishOperator(BaseOperator):
         *,
         target_arn: str,
         message: str,
+        subject: str | None = None,
+        message_attributes: dict | None = None,
         aws_conn_id: str = 'aws_default',
-        subject: Optional[str] = None,
-        message_attributes: Optional[dict] = None,
         **kwargs,
     ):
         super().__init__(**kwargs)
@@ -64,7 +64,7 @@ class SnsPublishOperator(BaseOperator):
         self.message_attributes = message_attributes
         self.aws_conn_id = aws_conn_id
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         sns = SnsHook(aws_conn_id=self.aws_conn_id)
 
         self.log.info(
