@@ -14,10 +14,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
+from __future__ import annotations
 
 import json
-from typing import TYPE_CHECKING, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
@@ -29,12 +29,13 @@ if TYPE_CHECKING:
 
 class StepFunctionStartExecutionOperator(BaseOperator):
     """
-    An Operator that begins execution of an Step Function State Machine
+    An Operator that begins execution of an AWS Step Function State Machine.
 
     Additional arguments may be specified and are passed down to the underlying BaseOperator.
 
     .. seealso::
-        :class:`~airflow.models.BaseOperator`
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:StepFunctionStartExecutionOperator`
 
     :param state_machine_arn: ARN of the Step Function State Machine
     :param name: The name of the execution.
@@ -51,10 +52,10 @@ class StepFunctionStartExecutionOperator(BaseOperator):
         self,
         *,
         state_machine_arn: str,
-        name: Optional[str] = None,
-        state_machine_input: Union[dict, str, None] = None,
+        name: str | None = None,
+        state_machine_input: dict | str | None = None,
         aws_conn_id: str = 'aws_default',
-        region_name: Optional[str] = None,
+        region_name: str | None = None,
         **kwargs,
     ):
         super().__init__(**kwargs)
@@ -64,7 +65,7 @@ class StepFunctionStartExecutionOperator(BaseOperator):
         self.aws_conn_id = aws_conn_id
         self.region_name = region_name
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = StepFunctionHook(aws_conn_id=self.aws_conn_id, region_name=self.region_name)
 
         execution_arn = hook.start_execution(self.state_machine_arn, self.name, self.input)
@@ -79,12 +80,13 @@ class StepFunctionStartExecutionOperator(BaseOperator):
 
 class StepFunctionGetExecutionOutputOperator(BaseOperator):
     """
-    An Operator that begins execution of an Step Function State Machine
+    An Operator that returns the output of an AWS Step Function State Machine execution.
 
     Additional arguments may be specified and are passed down to the underlying BaseOperator.
 
     .. seealso::
-        :class:`~airflow.models.BaseOperator`
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:StepFunctionGetExecutionOutputOperator`
 
     :param execution_arn: ARN of the Step Function State Machine Execution
     :param aws_conn_id: aws connection to use, defaults to 'aws_default'
@@ -99,7 +101,7 @@ class StepFunctionGetExecutionOutputOperator(BaseOperator):
         *,
         execution_arn: str,
         aws_conn_id: str = 'aws_default',
-        region_name: Optional[str] = None,
+        region_name: str | None = None,
         **kwargs,
     ):
         super().__init__(**kwargs)
@@ -107,7 +109,7 @@ class StepFunctionGetExecutionOutputOperator(BaseOperator):
         self.aws_conn_id = aws_conn_id
         self.region_name = region_name
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = StepFunctionHook(aws_conn_id=self.aws_conn_id, region_name=self.region_name)
 
         execution_status = hook.describe_execution(self.execution_arn)
