@@ -15,17 +15,14 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-import sys
-from typing import TYPE_CHECKING, Any, Optional, Sequence
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Any, Sequence
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
-if sys.version_info >= (3, 8):
-    from functools import cached_property
-else:
-    from cached_property import cached_property
-
+from airflow.compat.functools import cached_property
 from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.hooks.athena import AthenaHook
 from airflow.sensors.base import BaseSensorOperator
@@ -37,8 +34,8 @@ class AthenaSensor(BaseSensorOperator):
     If the query fails, the task will fail.
 
     .. seealso::
-        For more information on how to use this operator, take a look at the guide:
-        :ref:`howto/operator:AthenaSensor`
+        For more information on how to use this sensor, take a look at the guide:
+        :ref:`howto/sensor:AthenaSensor`
 
 
     :param query_execution_id: query_execution_id to check the state of
@@ -67,7 +64,7 @@ class AthenaSensor(BaseSensorOperator):
         self,
         *,
         query_execution_id: str,
-        max_retries: Optional[int] = None,
+        max_retries: int | None = None,
         aws_conn_id: str = 'aws_default',
         sleep_time: int = 10,
         **kwargs: Any,
@@ -78,7 +75,7 @@ class AthenaSensor(BaseSensorOperator):
         self.sleep_time = sleep_time
         self.max_retries = max_retries
 
-    def poke(self, context: 'Context') -> bool:
+    def poke(self, context: Context) -> bool:
         state = self.hook.poll_query_status(self.query_execution_id, self.max_retries)
 
         if state in self.FAILURE_STATES:
