@@ -15,15 +15,18 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import TYPE_CHECKING, Any, Dict, Iterable, Optional, Sequence
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Any, Iterable, Sequence
+
+from airflow.exceptions import AirflowException
+from airflow.providers.amazon.aws.hooks.emr import EmrContainerHook, EmrHook, EmrServerlessHook
+from airflow.sensors.base import BaseSensorOperator
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 from airflow.compat.functools import cached_property
-from airflow.exceptions import AirflowException
-from airflow.providers.amazon.aws.hooks.emr import EmrContainerHook, EmrHook
-from airflow.sensors.base import BaseSensorOperator
 
 
 class EmrBaseSensor(BaseSensorOperator):
@@ -37,7 +40,7 @@ class EmrBaseSensor(BaseSensorOperator):
 
     Subclasses should set ``target_states`` and ``failed_states`` fields.
 
-    :param aws_conn_id: aws connection to uses
+    :param aws_conn_id: aws connection to use
     """
 
     ui_color = '#66c3ff'
@@ -47,7 +50,7 @@ class EmrBaseSensor(BaseSensorOperator):
         self.aws_conn_id = aws_conn_id
         self.target_states: Iterable[str] = []  # will be set in subclasses
         self.failed_states: Iterable[str] = []  # will be set in subclasses
-        self.hook: Optional[EmrHook] = None
+        self.hook: EmrHook | None = None
 
     def get_hook(self) -> EmrHook:
         """Get EmrHook"""
@@ -57,7 +60,7 @@ class EmrBaseSensor(BaseSensorOperator):
         self.hook = EmrHook(aws_conn_id=self.aws_conn_id)
         return self.hook
 
-    def poke(self, context: 'Context'):
+    def poke(self, context: Context):
         response = self.get_emr_response()
 
         if response['ResponseMetadata']['HTTPStatusCode'] != 200:
@@ -79,7 +82,7 @@ class EmrBaseSensor(BaseSensorOperator):
 
         return False
 
-    def get_emr_response(self) -> Dict[str, Any]:
+    def get_emr_response(self) -> dict[str, Any]:
         """
         Make an API call with boto3 and get response.
 
@@ -89,7 +92,7 @@ class EmrBaseSensor(BaseSensorOperator):
         raise NotImplementedError('Please implement get_emr_response() in subclass')
 
     @staticmethod
-    def state_from_response(response: Dict[str, Any]) -> str:
+    def state_from_response(response: dict[str, Any]) -> str:
         """
         Get state from response dictionary.
 
@@ -100,7 +103,7 @@ class EmrBaseSensor(BaseSensorOperator):
         raise NotImplementedError('Please implement state_from_response() in subclass')
 
     @staticmethod
-    def failure_message_from_response(response: Dict[str, Any]) -> Optional[str]:
+    def failure_message_from_response(response: dict[str, Any]) -> str | None:
         """
         Get failure message from response dictionary.
 
@@ -111,6 +114,126 @@ class EmrBaseSensor(BaseSensorOperator):
         raise NotImplementedError('Please implement failure_message_from_response() in subclass')
 
 
+class EmrServerlessJobSensor(BaseSensorOperator):
+    """
+    Asks for the state of the job run until it reaches a failure state or success state.
+    If the job run fails, the task will fail.
+
+    .. seealso::
+        For more information on how to use this sensor, take a look at the guide:
+        :ref:`howto/sensor:EmrServerlessJobSensor`
+
+    :param application_id: application_id to check the state of
+    :param job_run_id: job_run_id to check the state of
+    :param target_states: a set of states to wait for, defaults to 'SUCCESS'
+    :param aws_conn_id: aws connection to use, defaults to 'aws_default'
+    """
+
+    template_fields: Sequence[str] = (
+        'application_id',
+        'job_run_id',
+    )
+
+    def __init__(
+        self,
+        *,
+        application_id: str,
+        job_run_id: str,
+        target_states: set | frozenset = frozenset(EmrServerlessHook.JOB_SUCCESS_STATES),
+        aws_conn_id: str = 'aws_default',
+        **kwargs: Any,
+    ) -> None:
+        self.aws_conn_id = aws_conn_id
+        self.target_states = target_states
+        self.application_id = application_id
+        self.job_run_id = job_run_id
+        super().__init__(**kwargs)
+
+    def poke(self, context: Context) -> bool:
+        response = self.hook.conn.get_job_run(applicationId=self.application_id, jobRunId=self.job_run_id)
+
+        state = response['jobRun']['state']
+
+        if state in EmrServerlessHook.JOB_FAILURE_STATES:
+            failure_message = f"EMR Serverless job failed: {self.failure_message_from_response(response)}"
+            raise AirflowException(failure_message)
+
+        return state in self.target_states
+
+    @cached_property
+    def hook(self) -> EmrServerlessHook:
+        """Create and return an EmrServerlessHook"""
+        return EmrServerlessHook(aws_conn_id=self.aws_conn_id)
+
+    @staticmethod
+    def failure_message_from_response(response: dict[str, Any]) -> str | None:
+        """
+        Get failure message from response dictionary.
+
+        :param response: response from AWS API
+        :return: failure message
+        :rtype: Optional[str]
+        """
+        return response['jobRun']['stateDetails']
+
+
+class EmrServerlessApplicationSensor(BaseSensorOperator):
+    """
+    Asks for the state of the application until it reaches a failure state or success state.
+    If the application fails, the task will fail.
+
+    .. seealso::
+        For more information on how to use this sensor, take a look at the guide:
+        :ref:`howto/sensor:EmrServerlessApplicationSensor`
+
+    :param application_id: application_id to check the state of
+    :param target_states: a set of states to wait for, defaults to {'CREATED', 'STARTED'}
+    :param aws_conn_id: aws connection to use, defaults to 'aws_default'
+    """
+
+    template_fields: Sequence[str] = ('application_id',)
+
+    def __init__(
+        self,
+        *,
+        application_id: str,
+        target_states: set | frozenset = frozenset(EmrServerlessHook.APPLICATION_SUCCESS_STATES),
+        aws_conn_id: str = 'aws_default',
+        **kwargs: Any,
+    ) -> None:
+        self.aws_conn_id = aws_conn_id
+        self.target_states = target_states
+        self.application_id = application_id
+        super().__init__(**kwargs)
+
+    def poke(self, context: Context) -> bool:
+        response = self.hook.conn.get_application(applicationId=self.application_id)
+
+        state = response['application']['state']
+
+        if state in EmrServerlessHook.APPLICATION_FAILURE_STATES:
+            failure_message = f"EMR Serverless job failed: {self.failure_message_from_response(response)}"
+            raise AirflowException(failure_message)
+
+        return state in self.target_states
+
+    @cached_property
+    def hook(self) -> EmrServerlessHook:
+        """Create and return an EmrServerlessHook"""
+        return EmrServerlessHook(aws_conn_id=self.aws_conn_id)
+
+    @staticmethod
+    def failure_message_from_response(response: dict[str, Any]) -> str | None:
+        """
+        Get failure message from response dictionary.
+
+        :param response: response from AWS API
+        :return: failure message
+        :rtype: Optional[str]
+        """
+        return response['application']['stateDetails']
+
+
 class EmrContainerSensor(BaseSensorOperator):
     """
     Asks for the state of the job run until it reaches a failure state or success state.
@@ -149,7 +272,7 @@ class EmrContainerSensor(BaseSensorOperator):
         *,
         virtual_cluster_id: str,
         job_id: str,
-        max_retries: Optional[int] = None,
+        max_retries: int | None = None,
         aws_conn_id: str = 'aws_default',
         poll_interval: int = 10,
         **kwargs: Any,
@@ -161,7 +284,7 @@ class EmrContainerSensor(BaseSensorOperator):
         self.poll_interval = poll_interval
         self.max_retries = max_retries
 
-    def poke(self, context: 'Context') -> bool:
+    def poke(self, context: Context) -> bool:
         state = self.hook.poll_query_status(self.job_id, self.max_retries, self.poll_interval)
 
         if state in self.FAILURE_STATES:
@@ -205,8 +328,8 @@ class EmrJobFlowSensor(EmrBaseSensor):
         self,
         *,
         job_flow_id: str,
-        target_states: Optional[Iterable[str]] = None,
-        failed_states: Optional[Iterable[str]] = None,
+        target_states: Iterable[str] | None = None,
+        failed_states: Iterable[str] | None = None,
         **kwargs,
     ):
         super().__init__(**kwargs)
@@ -214,7 +337,7 @@ class EmrJobFlowSensor(EmrBaseSensor):
         self.target_states = target_states or ['TERMINATED']
         self.failed_states = failed_states or ['TERMINATED_WITH_ERRORS']
 
-    def get_emr_response(self) -> Dict[str, Any]:
+    def get_emr_response(self) -> dict[str, Any]:
         """
         Make an API call with boto3 and get cluster-level details.
 
@@ -230,7 +353,7 @@ class EmrJobFlowSensor(EmrBaseSensor):
         return emr_client.describe_cluster(ClusterId=self.job_flow_id)
 
     @staticmethod
-    def state_from_response(response: Dict[str, Any]) -> str:
+    def state_from_response(response: dict[str, Any]) -> str:
         """
         Get state from response dictionary.
 
@@ -241,7 +364,7 @@ class EmrJobFlowSensor(EmrBaseSensor):
         return response['Cluster']['Status']['State']
 
     @staticmethod
-    def failure_message_from_response(response: Dict[str, Any]) -> Optional[str]:
+    def failure_message_from_response(response: dict[str, Any]) -> str | None:
         """
         Get failure message from response dictionary.
 
@@ -286,8 +409,8 @@ class EmrStepSensor(EmrBaseSensor):
         *,
         job_flow_id: str,
         step_id: str,
-        target_states: Optional[Iterable[str]] = None,
-        failed_states: Optional[Iterable[str]] = None,
+        target_states: Iterable[str] | None = None,
+        failed_states: Iterable[str] | None = None,
         **kwargs,
     ):
         super().__init__(**kwargs)
@@ -296,7 +419,7 @@ class EmrStepSensor(EmrBaseSensor):
         self.target_states = target_states or ['COMPLETED']
         self.failed_states = failed_states or ['CANCELLED', 'FAILED', 'INTERRUPTED']
 
-    def get_emr_response(self) -> Dict[str, Any]:
+    def get_emr_response(self) -> dict[str, Any]:
         """
         Make an API call with boto3 and get details about the cluster step.
 
@@ -312,7 +435,7 @@ class EmrStepSensor(EmrBaseSensor):
         return emr_client.describe_step(ClusterId=self.job_flow_id, StepId=self.step_id)
 
     @staticmethod
-    def state_from_response(response: Dict[str, Any]) -> str:
+    def state_from_response(response: dict[str, Any]) -> str:
         """
         Get state from response dictionary.
 
@@ -323,7 +446,7 @@ class EmrStepSensor(EmrBaseSensor):
         return response['Step']['Status']['State']
 
     @staticmethod
-    def failure_message_from_response(response: Dict[str, Any]) -> Optional[str]:
+    def failure_message_from_response(response: dict[str, Any]) -> str | None:
         """
         Get failure message from response dictionary.
 
