@@ -15,7 +15,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-import warnings
+from __future__ import annotations
+
 from typing import TYPE_CHECKING, Sequence
 
 from airflow.exceptions import AirflowException
@@ -37,43 +38,51 @@ class GlueJobSensor(BaseSensorOperator):
 
     :param job_name: The AWS Glue Job unique name
     :param run_id: The AWS Glue current running job identifier
+    :param verbose: If True, more Glue Job Run logs show in the Airflow Task Logs.  (default: False)
     """
 
     template_fields: Sequence[str] = ('job_name', 'run_id')
 
-    def __init__(self, *, job_name: str, run_id: str, aws_conn_id: str = 'aws_default', **kwargs):
+    def __init__(
+        self,
+        *,
+        job_name: str,
+        run_id: str,
+        verbose: bool = False,
+        aws_conn_id: str = 'aws_default',
+        **kwargs,
+    ):
         super().__init__(**kwargs)
         self.job_name = job_name
         self.run_id = run_id
+        self.verbose = verbose
         self.aws_conn_id = aws_conn_id
-        self.success_states = ['SUCCEEDED']
-        self.errored_states = ['FAILED', 'STOPPED', 'TIMEOUT']
+        self.success_states: list[str] = ['SUCCEEDED']
+        self.errored_states: list[str] = ['FAILED', 'STOPPED', 'TIMEOUT']
+        self.next_log_token: str | None = None
 
-    def poke(self, context: 'Context'):
+    def poke(self, context: Context):
         hook = GlueJobHook(aws_conn_id=self.aws_conn_id)
-        self.log.info("Poking for job run status :for Glue Job %s and ID %s", self.job_name, self.run_id)
+        self.log.info('Poking for job run status :for Glue Job %s and ID %s', self.job_name, self.run_id)
         job_state = hook.get_job_state(job_name=self.job_name, run_id=self.run_id)
-        if job_state in self.success_states:
-            self.log.info("Exiting Job %s Run State: %s", self.run_id, job_state)
-            return True
-        elif job_state in self.errored_states:
-            job_error_message = f"Exiting Job {self.run_id} Run State: {job_state}"
-            raise AirflowException(job_error_message)
-        else:
-            return False
+        job_failed = False
 
-
-class AwsGlueJobSensor(GlueJobSensor):
-    """
-    This sensor is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.sensors.glue.GlueJobSensor`.
-    """
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This sensor is deprecated. "
-            "Please use :class:`airflow.providers.amazon.aws.sensors.glue.GlueJobSensor`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        super().__init__(*args, **kwargs)
+        try:
+            if job_state in self.success_states:
+                self.log.info('Exiting Job %s Run State: %s', self.run_id, job_state)
+                return True
+            elif job_state in self.errored_states:
+                job_failed = True
+                job_error_message = 'Exiting Job %s Run State: %s', self.run_id, job_state
+                self.log.info(job_error_message)
+                raise AirflowException(job_error_message)
+            else:
+                return False
+        finally:
+            if self.verbose:
+                self.next_log_token = hook.print_job_logs(
+                    job_name=self.job_name,
+                    run_id=self.run_id,
+                    job_failed=job_failed,
+                    next_token=self.next_log_token,
+                )
