@@ -15,8 +15,9 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-import warnings
-from typing import TYPE_CHECKING, Optional, Sequence
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.providers.amazon.aws.hooks.glue_catalog import GlueCatalogHook
 from airflow.sensors.base import BaseSensorOperator
@@ -31,25 +32,19 @@ class GlueCatalogPartitionSensor(BaseSensorOperator):
 
     :param table_name: The name of the table to wait for, supports the dot
         notation (my_database.my_table)
-    :type table_name: str
     :param expression: The partition clause to wait for. This is passed as
         is to the AWS Glue Catalog API's get_partitions function,
         and supports SQL like notation as in ``ds='2015-01-01'
         AND type='value'`` and comparison operators as in ``"ds>=2015-01-01"``.
         See https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html
         #aws-glue-api-catalog-partitions-GetPartitions
-    :type expression: str
     :param aws_conn_id: ID of the Airflow connection where
         credentials and extra configuration are stored
-    :type aws_conn_id: str
     :param region_name: Optional aws region name (example: us-east-1). Uses region from connection
         if not specified.
-    :type region_name: str
     :param database_name: The name of the catalog database where the partitions reside.
-    :type database_name: str
     :param poke_interval: Time in seconds that the job should wait in
         between each tries
-    :type poke_interval: int
     """
 
     template_fields: Sequence[str] = (
@@ -65,7 +60,7 @@ class GlueCatalogPartitionSensor(BaseSensorOperator):
         table_name: str,
         expression: str = "ds='{{ ds }}'",
         aws_conn_id: str = 'aws_default',
-        region_name: Optional[str] = None,
+        region_name: str | None = None,
         database_name: str = 'default',
         poke_interval: int = 60 * 3,
         **kwargs,
@@ -76,9 +71,9 @@ class GlueCatalogPartitionSensor(BaseSensorOperator):
         self.table_name = table_name
         self.expression = expression
         self.database_name = database_name
-        self.hook: Optional[GlueCatalogHook] = None
+        self.hook: GlueCatalogHook | None = None
 
-    def poke(self, context: 'Context'):
+    def poke(self, context: Context):
         """Checks for existence of the partition in the AWS Glue Catalog table"""
         if '.' in self.table_name:
             self.database_name, self.table_name = self.table_name.split('.')
@@ -95,19 +90,3 @@ class GlueCatalogPartitionSensor(BaseSensorOperator):
 
         self.hook = GlueCatalogHook(aws_conn_id=self.aws_conn_id, region_name=self.region_name)
         return self.hook
-
-
-class AwsGlueCatalogPartitionSensor(GlueCatalogPartitionSensor):
-    """
-    This sensor is deprecated. Please use
-    :class:`airflow.providers.amazon.aws.sensors.glue_catalog_partition.GlueCatalogPartitionSensor`.
-    """
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This sensor is deprecated. "
-            "Please use :class:`airflow.providers.amazon.aws.sensors.glue_catalog_partition.GlueCatalogPartitionSensor`.",  # noqa: 501
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        super().__init__(*args, **kwargs)
