@@ -14,8 +14,9 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
-from typing import TYPE_CHECKING, List, Optional, Sequence
+from typing import TYPE_CHECKING, Sequence
 
 from botocore.exceptions import ClientError
 
@@ -34,14 +35,13 @@ class RdsBaseSensor(BaseSensorOperator):
     ui_color = "#ddbb77"
     ui_fgcolor = "#ffffff"
 
-    def __init__(self, *args, aws_conn_id: str = "aws_conn_id", hook_params: Optional[dict] = None, **kwargs):
+    def __init__(self, *args, aws_conn_id: str = "aws_conn_id", hook_params: dict | None = None, **kwargs):
         hook_params = hook_params or {}
         self.hook = RdsHook(aws_conn_id=aws_conn_id, **hook_params)
-        self.target_statuses: List[str] = []
+        self.target_statuses: list[str] = []
         super().__init__(*args, **kwargs)
 
     def _describe_item(self, item_type: str, item_name: str) -> list:
-
         if item_type == 'instance_snapshot':
             db_snaps = self.hook.conn.describe_db_snapshots(DBSnapshotIdentifier=item_name)
             return db_snaps['DBSnapshots']
@@ -51,18 +51,29 @@ class RdsBaseSensor(BaseSensorOperator):
         elif item_type == 'export_task':
             exports = self.hook.conn.describe_export_tasks(ExportTaskIdentifier=item_name)
             return exports['ExportTasks']
+        elif item_type == "db_instance":
+            instances = self.hook.conn.describe_db_instances(DBInstanceIdentifier=item_name)
+            return instances["DBInstances"]
+        elif item_type == "db_cluster":
+            clusters = self.hook.conn.describe_db_clusters(DBClusterIdentifier=item_name)
+            return clusters["DBClusters"]
         else:
             raise AirflowException(f"Method for {item_type} is not implemented")
 
     def _check_item(self, item_type: str, item_name: str) -> bool:
         """Get certain item from `_describe_item()` and check its status"""
-
+        if item_type == "db_instance":
+            status_field = "DBInstanceStatus"
+        else:
+            status_field = "Status"
         try:
             items = self._describe_item(item_type, item_name)
         except ClientError:
             return False
         else:
-            return bool(items) and any(map(lambda s: items[0]['Status'].lower() == s, self.target_statuses))
+            return bool(items) and any(
+                map(lambda status: items[0][status_field].lower() == status, self.target_statuses)
+            )
 
 
 class RdsSnapshotExistenceSensor(RdsBaseSensor):
@@ -70,8 +81,8 @@ class RdsSnapshotExistenceSensor(RdsBaseSensor):
     Waits for RDS snapshot with a specific status.
 
     .. seealso::
-        For more information on how to use this operator, take a look at the guide:
-        :ref:`howto/operator:RdsSnapshotExistenceSensor`
+        For more information on how to use this sensor, take a look at the guide:
+        :ref:`howto/sensor:RdsSnapshotExistenceSensor`
 
     :param db_type: Type of the DB - either "instance" or "cluster"
     :param db_snapshot_identifier: The identifier for the DB snapshot
@@ -88,7 +99,7 @@ class RdsSnapshotExistenceSensor(RdsBaseSensor):
         *,
         db_type: str,
         db_snapshot_identifier: str,
-        target_statuses: Optional[List[str]] = None,
+        target_statuses: list[str] | None = None,
         aws_conn_id: str = "aws_conn_id",
         **kwargs,
     ):
@@ -97,7 +108,7 @@ class RdsSnapshotExistenceSensor(RdsBaseSensor):
         self.db_snapshot_identifier = db_snapshot_identifier
         self.target_statuses = target_statuses or ['available']
 
-    def poke(self, context: 'Context'):
+    def poke(self, context: Context):
         self.log.info(
             'Poking for statuses : %s\nfor snapshot %s', self.target_statuses, self.db_snapshot_identifier
         )
@@ -112,8 +123,8 @@ class RdsExportTaskExistenceSensor(RdsBaseSensor):
     Waits for RDS export task with a specific status.
 
     .. seealso::
-        For more information on how to use this operator, take a look at the guide:
-        :ref:`howto/operator:RdsExportTaskExistenceSensor`
+        For more information on how to use this sensor, take a look at the guide:
+        :ref:`howto/sensor:RdsExportTaskExistenceSensor`
 
     :param export_task_identifier: A unique identifier for the snapshot export task.
     :param target_statuses: Target status of export task
@@ -128,7 +139,7 @@ class RdsExportTaskExistenceSensor(RdsBaseSensor):
         self,
         *,
         export_task_identifier: str,
-        target_statuses: Optional[List[str]] = None,
+        target_statuses: list[str] | None = None,
         aws_conn_id: str = "aws_default",
         **kwargs,
     ):
@@ -143,14 +154,55 @@ class RdsExportTaskExistenceSensor(RdsBaseSensor):
             'canceled',
         ]
 
-    def poke(self, context: 'Context'):
+    def poke(self, context: Context):
         self.log.info(
             'Poking for statuses : %s\nfor export task %s', self.target_statuses, self.export_task_identifier
         )
         return self._check_item(item_type='export_task', item_name=self.export_task_identifier)
 
 
+class RdsDbSensor(RdsBaseSensor):
+    """
+    Waits for an RDS instance or cluster to enter one of a number of states
+
+    .. seealso::
+        For more information on how to use this sensor, take a look at the guide:
+        :ref:`howto/sensor:RdsDbSensor`
+
+    :param db_type: Type of the DB - either "instance" or "cluster"
+    :param db_identifier: The AWS identifier for the DB
+    :param target_statuses: Target status of DB
+    """
+
+    def __init__(
+        self,
+        *,
+        db_identifier: str,
+        db_type: str = "instance",
+        target_statuses: list[str] | None = None,
+        aws_conn_id: str = "aws_default",
+        **kwargs,
+    ):
+        super().__init__(aws_conn_id=aws_conn_id, **kwargs)
+        self.db_identifier = db_identifier
+        self.target_statuses = target_statuses or ["available"]
+        self.db_type = RdsDbType(db_type)
+
+    def poke(self, context: Context):
+        self.log.info(
+            "Poking for statuses : %s\nfor db instance %s", self.target_statuses, self.db_identifier
+        )
+        item_type = self._check_item_type()
+        return self._check_item(item_type=item_type, item_name=self.db_identifier)
+
+    def _check_item_type(self):
+        if self.db_type == RdsDbType.CLUSTER:
+            return "db_cluster"
+        return "db_instance"
+
+
 __all__ = [
     "RdsExportTaskExistenceSensor",
+    "RdsDbSensor",
     "RdsSnapshotExistenceSensor",
 ]
