@@ -14,8 +14,9 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
-from typing import TYPE_CHECKING, Optional, Sequence
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.providers.amazon.aws.hooks.redshift_cluster import RedshiftHook
 from airflow.sensors.base import BaseSensorOperator
@@ -24,14 +25,16 @@ if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-class AwsRedshiftClusterSensor(BaseSensorOperator):
+class RedshiftClusterSensor(BaseSensorOperator):
     """
     Waits for a Redshift cluster to reach a specific status.
 
+    .. seealso::
+        For more information on how to use this sensor, take a look at the guide:
+        :ref:`howto/sensor:RedshiftClusterSensor`
+
     :param cluster_identifier: The identifier for the cluster being pinged.
-    :type cluster_identifier: str
     :param target_status: The cluster status desired.
-    :type target_status: str
     """
 
     template_fields: Sequence[str] = ('cluster_identifier', 'target_status')
@@ -48,9 +51,9 @@ class AwsRedshiftClusterSensor(BaseSensorOperator):
         self.cluster_identifier = cluster_identifier
         self.target_status = target_status
         self.aws_conn_id = aws_conn_id
-        self.hook: Optional[RedshiftHook] = None
+        self.hook: RedshiftHook | None = None
 
-    def poke(self, context: 'Context'):
+    def poke(self, context: Context):
         self.log.info('Poking for status : %s\nfor cluster %s', self.target_status, self.cluster_identifier)
         return self.get_hook().cluster_status(self.cluster_identifier) == self.target_status
 
