@@ -16,6 +16,9 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module allows you to transfer mail attachments from a mail server into s3 bucket."""
+from __future__ import annotations
+
+import warnings
 from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
@@ -25,6 +28,10 @@ from airflow.providers.imap.hooks.imap import ImapHook
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
+_DEPRECATION_MSG = (
+    "The s3_conn_id parameter has been deprecated. You should pass instead the aws_conn_id parameter."
+)
+
 
 class ImapAttachmentToS3Operator(BaseOperator):
     """
@@ -35,6 +42,7 @@ class ImapAttachmentToS3Operator(BaseOperator):
         :ref:`howto/operator:ImapAttachmentToS3Operator`
 
     :param imap_attachment_name: The file name of the mail attachment that you want to transfer.
+    :param s3_bucket: The targeted s3 bucket. This is the S3 bucket where the file will be downloaded.
     :param s3_key: The destination file name in the s3 bucket for the attachment.
     :param imap_check_regex: If set checks the `imap_attachment_name` for a regular expression.
     :param imap_mail_folder: The folder on the mail server to look for the attachment.
@@ -42,7 +50,7 @@ class ImapAttachmentToS3Operator(BaseOperator):
         See :py:meth:`imaplib.IMAP4.search` for details.
     :param s3_overwrite: If set overwrites the s3 key if already exists.
     :param imap_conn_id: The reference to the connection details of the mail server.
-    :param s3_conn_id: The reference to the s3 connection details.
+    :param aws_conn_id: AWS connection to use.
     """
 
     template_fields: Sequence[str] = ('imap_attachment_name', 's3_key', 'imap_mail_filter')
@@ -51,26 +59,33 @@ class ImapAttachmentToS3Operator(BaseOperator):
         self,
         *,
         imap_attachment_name: str,
+        s3_bucket: str,
         s3_key: str,
         imap_check_regex: bool = False,
         imap_mail_folder: str = 'INBOX',
         imap_mail_filter: str = 'All',
         s3_overwrite: bool = False,
         imap_conn_id: str = 'imap_default',
-        s3_conn_id: str = 'aws_default',
+        s3_conn_id: str | None = None,
+        aws_conn_id: str = 'aws_default',
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
+        if s3_conn_id:
+            warnings.warn(_DEPRECATION_MSG, DeprecationWarning, stacklevel=3)
+            aws_conn_id = s3_conn_id
+
         self.imap_attachment_name = imap_attachment_name
+        self.s3_bucket = s3_bucket
         self.s3_key = s3_key
         self.imap_check_regex = imap_check_regex
         self.imap_mail_folder = imap_mail_folder
         self.imap_mail_filter = imap_mail_filter
         self.s3_overwrite = s3_overwrite
         self.imap_conn_id = imap_conn_id
-        self.s3_conn_id = s3_conn_id
+        self.aws_conn_id = aws_conn_id
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         """
         This function executes the transfer from the email server (via imap) into s3.
 
@@ -91,5 +106,10 @@ class ImapAttachmentToS3Operator(BaseOperator):
                 mail_filter=self.imap_mail_filter,
             )
 
-        s3_hook = S3Hook(aws_conn_id=self.s3_conn_id)
-        s3_hook.load_bytes(bytes_data=imap_mail_attachments[0][1], key=self.s3_key, replace=self.s3_overwrite)
+        s3_hook = S3Hook(aws_conn_id=self.aws_conn_id)
+        s3_hook.load_bytes(
+            bytes_data=imap_mail_attachments[0][1],
+            bucket_name=self.s3_bucket,
+            key=self.s3_key,
+            replace=self.s3_overwrite,
+        )
