@@ -14,9 +14,9 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
-import warnings
-from typing import TYPE_CHECKING, List, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Iterable, Sequence
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
@@ -64,7 +64,15 @@ class S3ToRedshiftOperator(BaseOperator):
     :param upsert_keys: List of fields to use as key on upsert action
     """
 
-    template_fields: Sequence[str] = ('s3_bucket', 's3_key', 'schema', 'table', 'column_list', 'copy_options')
+    template_fields: Sequence[str] = (
+        's3_bucket',
+        's3_key',
+        'schema',
+        'table',
+        'column_list',
+        'copy_options',
+        'redshift_conn_id',
+    )
     template_ext: Sequence[str] = ()
     ui_color = '#99e699'
 
@@ -77,25 +85,14 @@ class S3ToRedshiftOperator(BaseOperator):
         s3_key: str,
         redshift_conn_id: str = 'redshift_default',
         aws_conn_id: str = 'aws_default',
-        verify: Optional[Union[bool, str]] = None,
-        column_list: Optional[List[str]] = None,
-        copy_options: Optional[List] = None,
+        verify: bool | str | None = None,
+        column_list: list[str] | None = None,
+        copy_options: list | None = None,
         autocommit: bool = False,
         method: str = 'APPEND',
-        upsert_keys: Optional[List[str]] = None,
+        upsert_keys: list[str] | None = None,
         **kwargs,
     ) -> None:
-
-        if 'truncate_table' in kwargs:
-            warnings.warn(
-                """`truncate_table` is deprecated. Please use `REPLACE` method.""",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-            if kwargs['truncate_table']:
-                method = 'REPLACE'
-            kwargs.pop('truncate_table', None)
-
         super().__init__(**kwargs)
         self.schema = schema
         self.table = table
@@ -123,11 +120,10 @@ class S3ToRedshiftOperator(BaseOperator):
                     {copy_options};
         """
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         redshift_hook = RedshiftSQLHook(redshift_conn_id=self.redshift_conn_id)
         conn = S3Hook.get_connection(conn_id=self.aws_conn_id)
 
-        credentials_block = None
         if conn.extra_dejson.get('role_arn', False):
             credentials_block = f"aws_iam_role={conn.extra_dejson['role_arn']}"
         else:
@@ -141,7 +137,7 @@ class S3ToRedshiftOperator(BaseOperator):
 
         copy_statement = self._build_copy_query(copy_destination, credentials_block, copy_options)
 
-        sql: Union[list, str]
+        sql: str | Iterable[str]
 
         if self.method == 'REPLACE':
             sql = ["BEGIN;", f"DELETE FROM {destination};", copy_statement, "COMMIT"]
